/* Parser.c generated by valac 0.44.3, the Vala compiler
 * generated from Parser.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; c-basic-offset: 2; tab-width: 2 -*- */
/* Parser.vala
 *
 * Copyright (C) 2016-2019  Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <glib.h>
#include <glib-object.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <glib/gi18n-lib.h>

#define GXML_TYPE_PARSER (gxml_parser_get_type ())
#define GXML_PARSER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_PARSER, GXmlParser))
#define GXML_IS_PARSER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_PARSER))
#define GXML_PARSER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_PARSER, GXmlParserIface))

typedef struct _GXmlParser GXmlParser;
typedef struct _GXmlParserIface GXmlParserIface;

#define GXML_TYPE_DOM_NODE (gxml_dom_node_get_type ())
#define GXML_DOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE, GXmlDomNode))
#define GXML_IS_DOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE))
#define GXML_DOM_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE, GXmlDomNodeIface))

typedef struct _GXmlDomNode GXmlDomNode;
typedef struct _GXmlDomNodeIface GXmlDomNodeIface;

#define GXML_TYPE_DOM_EVENT_TARGET (gxml_dom_event_target_get_type ())
#define GXML_DOM_EVENT_TARGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT_TARGET, GXmlDomEventTarget))
#define GXML_IS_DOM_EVENT_TARGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT_TARGET))
#define GXML_DOM_EVENT_TARGET_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT_TARGET, GXmlDomEventTargetIface))

typedef struct _GXmlDomEventTarget GXmlDomEventTarget;
typedef struct _GXmlDomEventTargetIface GXmlDomEventTargetIface;

#define GXML_TYPE_DOM_EVENT_LISTENER (gxml_dom_event_listener_get_type ())
#define GXML_DOM_EVENT_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT_LISTENER, GXmlDomEventListener))
#define GXML_IS_DOM_EVENT_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT_LISTENER))
#define GXML_DOM_EVENT_LISTENER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT_LISTENER, GXmlDomEventListenerIface))

typedef struct _GXmlDomEventListener GXmlDomEventListener;
typedef struct _GXmlDomEventListenerIface GXmlDomEventListenerIface;

#define GXML_TYPE_DOM_EVENT (gxml_dom_event_get_type ())
#define GXML_DOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT, GXmlDomEvent))
#define GXML_IS_DOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT))
#define GXML_DOM_EVENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT, GXmlDomEventIface))

typedef struct _GXmlDomEvent GXmlDomEvent;
typedef struct _GXmlDomEventIface GXmlDomEventIface;

#define GXML_TYPE_DOM_TIME_STAMP (gxml_dom_time_stamp_get_type ())
#define GXML_DOM_TIME_STAMP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStamp))
#define GXML_DOM_TIME_STAMP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStampClass))
#define GXML_IS_DOM_TIME_STAMP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TIME_STAMP))
#define GXML_IS_DOM_TIME_STAMP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_TIME_STAMP))
#define GXML_DOM_TIME_STAMP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStampClass))

typedef struct _GXmlDomTimeStamp GXmlDomTimeStamp;
typedef struct _GXmlDomTimeStampClass GXmlDomTimeStampClass;
typedef enum  {
	GXML_DOM_EVENT_PHASE_NONE = 0,
	GXML_DOM_EVENT_PHASE_CAPTURING_PHASE,
	GXML_DOM_EVENT_PHASE_AT_TARGET,
	GXML_DOM_EVENT_PHASE_BUBBLING_PHASE
} GXmlDomEventPhase;

#define GXML_DOM_EVENT_TYPE_PHASE (gxml_dom_event_phase_get_type ())
typedef enum  {
	GXML_DOM_NODE_DOCUMENT_POSITION_NONE = 1 << 0,
	GXML_DOM_NODE_DOCUMENT_POSITION_DISCONNECTED = 1 << 1,
	GXML_DOM_NODE_DOCUMENT_POSITION_PRECEDING = 1 << 2,
	GXML_DOM_NODE_DOCUMENT_POSITION_FOLLOWING = 1 << 3,
	GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINS = 1 << 4,
	GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINED_BY = 1 << 5,
	GXML_DOM_NODE_DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC = 1 << 6
} GXmlDomNodeDocumentPosition;

#define GXML_DOM_NODE_TYPE_DOCUMENT_POSITION (gxml_dom_node_document_position_get_type ())
typedef enum  {
	GXML_DOM_NODE_NODE_TYPE_INVALID = 0,
	GXML_DOM_NODE_NODE_TYPE_ELEMENT_NODE = 1,
	GXML_DOM_NODE_NODE_TYPE_ATTRIBUTE_NODE,
	GXML_DOM_NODE_NODE_TYPE_TEXT_NODE,
	GXML_DOM_NODE_NODE_TYPE_CDATA_SECTION_NODE,
	GXML_DOM_NODE_NODE_TYPE_ENTITY_REFERENCE_NODE,
	GXML_DOM_NODE_NODE_TYPE_ENTITY_NODE,
	GXML_DOM_NODE_NODE_TYPE_PROCESSING_INSTRUCTION_NODE,
	GXML_DOM_NODE_NODE_TYPE_COMMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_TYPE_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_FRAGMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_NOTATION_NODE
} GXmlDomNodeNodeType;

#define GXML_DOM_NODE_TYPE_NODE_TYPE (gxml_dom_node_node_type_get_type ())

#define GXML_TYPE_DOM_DOCUMENT (gxml_dom_document_get_type ())
#define GXML_DOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT, GXmlDomDocument))
#define GXML_IS_DOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT))
#define GXML_DOM_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT, GXmlDomDocumentIface))

typedef struct _GXmlDomDocument GXmlDomDocument;
typedef struct _GXmlDomDocumentIface GXmlDomDocumentIface;

#define GXML_TYPE_DOM_PARENT_NODE (gxml_dom_parent_node_get_type ())
#define GXML_DOM_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_PARENT_NODE, GXmlDomParentNode))
#define GXML_IS_DOM_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_PARENT_NODE))
#define GXML_DOM_PARENT_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_PARENT_NODE, GXmlDomParentNodeIface))

typedef struct _GXmlDomParentNode GXmlDomParentNode;
typedef struct _GXmlDomParentNodeIface GXmlDomParentNodeIface;

#define GXML_TYPE_DOM_ELEMENT (gxml_dom_element_get_type ())
#define GXML_DOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ELEMENT, GXmlDomElement))
#define GXML_IS_DOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ELEMENT))
#define GXML_DOM_ELEMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_ELEMENT, GXmlDomElementIface))

typedef struct _GXmlDomElement GXmlDomElement;
typedef struct _GXmlDomElementIface GXmlDomElementIface;

#define GXML_TYPE_DOM_CHILD_NODE (gxml_dom_child_node_get_type ())
#define GXML_DOM_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_CHILD_NODE, GXmlDomChildNode))
#define GXML_IS_DOM_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_CHILD_NODE))
#define GXML_DOM_CHILD_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_CHILD_NODE, GXmlDomChildNodeIface))

typedef struct _GXmlDomChildNode GXmlDomChildNode;
typedef struct _GXmlDomChildNodeIface GXmlDomChildNodeIface;

#define GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE (gxml_dom_non_document_type_child_node_get_type ())
#define GXML_DOM_NON_DOCUMENT_TYPE_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE, GXmlDomNonDocumentTypeChildNode))
#define GXML_IS_DOM_NON_DOCUMENT_TYPE_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE))
#define GXML_DOM_NON_DOCUMENT_TYPE_CHILD_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE, GXmlDomNonDocumentTypeChildNodeIface))

typedef struct _GXmlDomNonDocumentTypeChildNode GXmlDomNonDocumentTypeChildNode;
typedef struct _GXmlDomNonDocumentTypeChildNodeIface GXmlDomNonDocumentTypeChildNodeIface;

#define GXML_TYPE_DOM_HTML_COLLECTION (gxml_dom_html_collection_get_type ())
#define GXML_DOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_HTML_COLLECTION, GXmlDomHTMLCollection))
#define GXML_IS_DOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_HTML_COLLECTION))
#define GXML_DOM_HTML_COLLECTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_HTML_COLLECTION, GXmlDomHTMLCollectionIface))

typedef struct _GXmlDomHTMLCollection GXmlDomHTMLCollection;
typedef struct _GXmlDomHTMLCollectionIface GXmlDomHTMLCollectionIface;

#define GXML_TYPE_DOM_TOKEN_LIST (gxml_dom_token_list_get_type ())
#define GXML_DOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TOKEN_LIST, GXmlDomTokenList))
#define GXML_IS_DOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TOKEN_LIST))
#define GXML_DOM_TOKEN_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TOKEN_LIST, GXmlDomTokenListIface))

typedef struct _GXmlDomTokenList GXmlDomTokenList;
typedef struct _GXmlDomTokenListIface GXmlDomTokenListIface;

#define GXML_TYPE_DOM_NAMED_NODE_MAP (gxml_dom_named_node_map_get_type ())
#define GXML_DOM_NAMED_NODE_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP, GXmlDomNamedNodeMap))
#define GXML_IS_DOM_NAMED_NODE_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP))
#define GXML_DOM_NAMED_NODE_MAP_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP, GXmlDomNamedNodeMapIface))

typedef struct _GXmlDomNamedNodeMap GXmlDomNamedNodeMap;
typedef struct _GXmlDomNamedNodeMapIface GXmlDomNamedNodeMapIface;

#define GXML_TYPE_DOM_NODE_LIST (gxml_dom_node_list_get_type ())
#define GXML_DOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_LIST, GXmlDomNodeList))
#define GXML_IS_DOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_LIST))
#define GXML_DOM_NODE_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE_LIST, GXmlDomNodeListIface))

typedef struct _GXmlDomNodeList GXmlDomNodeList;
typedef struct _GXmlDomNodeListIface GXmlDomNodeListIface;

#define GXML_TYPE_DOM_ELEMENT_LIST (gxml_dom_element_list_get_type ())
#define GXML_DOM_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementList))
#define GXML_DOM_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementListClass))
#define GXML_IS_DOM_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ELEMENT_LIST))
#define GXML_IS_DOM_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_ELEMENT_LIST))
#define GXML_DOM_ELEMENT_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementListClass))

typedef struct _GXmlDomElementList GXmlDomElementList;
typedef struct _GXmlDomElementListClass GXmlDomElementListClass;

#define GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE (gxml_dom_non_element_parent_node_get_type ())
#define GXML_DOM_NON_ELEMENT_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE, GXmlDomNonElementParentNode))
#define GXML_IS_DOM_NON_ELEMENT_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE))
#define GXML_DOM_NON_ELEMENT_PARENT_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE, GXmlDomNonElementParentNodeIface))

typedef struct _GXmlDomNonElementParentNode GXmlDomNonElementParentNode;
typedef struct _GXmlDomNonElementParentNodeIface GXmlDomNonElementParentNodeIface;

#define GXML_TYPE_DOM_DOCUMENT_FRAGMENT (gxml_dom_document_fragment_get_type ())
#define GXML_DOM_DOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT, GXmlDomDocumentFragment))
#define GXML_IS_DOM_DOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT))
#define GXML_DOM_DOCUMENT_FRAGMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT, GXmlDomDocumentFragmentIface))

typedef struct _GXmlDomDocumentFragment GXmlDomDocumentFragment;
typedef struct _GXmlDomDocumentFragmentIface GXmlDomDocumentFragmentIface;

#define GXML_TYPE_DOM_TEXT (gxml_dom_text_get_type ())
#define GXML_DOM_TEXT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TEXT, GXmlDomText))
#define GXML_IS_DOM_TEXT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TEXT))
#define GXML_DOM_TEXT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TEXT, GXmlDomTextIface))

typedef struct _GXmlDomText GXmlDomText;
typedef struct _GXmlDomTextIface GXmlDomTextIface;

#define GXML_TYPE_DOM_CHARACTER_DATA (gxml_dom_character_data_get_type ())
#define GXML_DOM_CHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_CHARACTER_DATA, GXmlDomCharacterData))
#define GXML_IS_DOM_CHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_CHARACTER_DATA))
#define GXML_DOM_CHARACTER_DATA_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_CHARACTER_DATA, GXmlDomCharacterDataIface))

typedef struct _GXmlDomCharacterData GXmlDomCharacterData;
typedef struct _GXmlDomCharacterDataIface GXmlDomCharacterDataIface;

#define GXML_TYPE_DOM_COMMENT (gxml_dom_comment_get_type ())
#define GXML_DOM_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_COMMENT, GXmlDomComment))
#define GXML_IS_DOM_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_COMMENT))
#define GXML_DOM_COMMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_COMMENT, GXmlDomCommentIface))

typedef struct _GXmlDomComment GXmlDomComment;
typedef struct _GXmlDomCommentIface GXmlDomCommentIface;

#define GXML_TYPE_DOM_PROCESSING_INSTRUCTION (gxml_dom_processing_instruction_get_type ())
#define GXML_DOM_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION, GXmlDomProcessingInstruction))
#define GXML_IS_DOM_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION))
#define GXML_DOM_PROCESSING_INSTRUCTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION, GXmlDomProcessingInstructionIface))

typedef struct _GXmlDomProcessingInstruction GXmlDomProcessingInstruction;
typedef struct _GXmlDomProcessingInstructionIface GXmlDomProcessingInstructionIface;

#define GXML_TYPE_DOM_RANGE (gxml_dom_range_get_type ())
#define GXML_DOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_RANGE, GXmlDomRange))
#define GXML_IS_DOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_RANGE))
#define GXML_DOM_RANGE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_RANGE, GXmlDomRangeIface))

typedef struct _GXmlDomRange GXmlDomRange;
typedef struct _GXmlDomRangeIface GXmlDomRangeIface;
typedef enum  {
	GXML_DOM_RANGE_BOUNDARY_POINTS_START_TO_START = 0,
	GXML_DOM_RANGE_BOUNDARY_POINTS_START_TO_END,
	GXML_DOM_RANGE_BOUNDARY_POINTS_END_TO_END,
	GXML_DOM_RANGE_BOUNDARY_POINTS_END_TO_START
} GXmlDomRangeBoundaryPoints;

#define GXML_DOM_RANGE_TYPE_BOUNDARY_POINTS (gxml_dom_range_boundary_points_get_type ())

#define GXML_TYPE_DOM_NODE_FILTER (gxml_dom_node_filter_get_type ())
#define GXML_DOM_NODE_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilter))
#define GXML_DOM_NODE_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilterClass))
#define GXML_IS_DOM_NODE_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_FILTER))
#define GXML_IS_DOM_NODE_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_NODE_FILTER))
#define GXML_DOM_NODE_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilterClass))

typedef struct _GXmlDomNodeFilter GXmlDomNodeFilter;
typedef struct _GXmlDomNodeFilterClass GXmlDomNodeFilterClass;

#define GXML_TYPE_DOM_NODE_ITERATOR (gxml_dom_node_iterator_get_type ())
#define GXML_DOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_ITERATOR, GXmlDomNodeIterator))
#define GXML_IS_DOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_ITERATOR))
#define GXML_DOM_NODE_ITERATOR_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE_ITERATOR, GXmlDomNodeIteratorIface))

typedef struct _GXmlDomNodeIterator GXmlDomNodeIterator;
typedef struct _GXmlDomNodeIteratorIface GXmlDomNodeIteratorIface;

#define GXML_TYPE_DOM_TREE_WALKER (gxml_dom_tree_walker_get_type ())
#define GXML_DOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TREE_WALKER, GXmlDomTreeWalker))
#define GXML_IS_DOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TREE_WALKER))
#define GXML_DOM_TREE_WALKER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TREE_WALKER, GXmlDomTreeWalkerIface))

typedef struct _GXmlDomTreeWalker GXmlDomTreeWalker;
typedef struct _GXmlDomTreeWalkerIface GXmlDomTreeWalkerIface;

#define GXML_TYPE_DOM_IMPLEMENTATION (gxml_dom_implementation_get_type ())
#define GXML_DOM_IMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_IMPLEMENTATION, GXmlDomImplementation))
#define GXML_IS_DOM_IMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_IMPLEMENTATION))
#define GXML_DOM_IMPLEMENTATION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_IMPLEMENTATION, GXmlDomImplementationIface))

typedef struct _GXmlDomImplementation GXmlDomImplementation;
typedef struct _GXmlDomImplementationIface GXmlDomImplementationIface;

#define GXML_TYPE_DOM_DOCUMENT_TYPE (gxml_dom_document_type_get_type ())
#define GXML_DOM_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE, GXmlDomDocumentType))
#define GXML_IS_DOM_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE))
#define GXML_DOM_DOCUMENT_TYPE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE, GXmlDomDocumentTypeIface))

typedef struct _GXmlDomDocumentType GXmlDomDocumentType;
typedef struct _GXmlDomDocumentTypeIface GXmlDomDocumentTypeIface;

#define GXML_TYPE_DOM_XML_DOCUMENT (gxml_dom_xml_document_get_type ())
#define GXML_DOM_XML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_XML_DOCUMENT, GXmlDomXMLDocument))
#define GXML_IS_DOM_XML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_XML_DOCUMENT))
#define GXML_DOM_XML_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_XML_DOCUMENT, GXmlDomXMLDocumentIface))

typedef struct _GXmlDomXMLDocument GXmlDomXMLDocument;
typedef struct _GXmlDomXMLDocumentIface GXmlDomXMLDocumentIface;

#define GXML_TYPE_DOCUMENT (gxml_document_get_type ())
#define GXML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOCUMENT, GXmlDocument))
#define GXML_IS_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOCUMENT))
#define GXML_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOCUMENT, GXmlDocumentIface))

typedef struct _GXmlDocument GXmlDocument;
typedef struct _GXmlDocumentIface GXmlDocumentIface;

#define GXML_TYPE_NODE (gxml_node_get_type ())
#define GXML_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NODE, GXmlNode))
#define GXML_IS_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NODE))
#define GXML_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_NODE, GXmlNodeIface))

typedef struct _GXmlNode GXmlNode;
typedef struct _GXmlNodeIface GXmlNodeIface;

#define GXML_TYPE_ELEMENT_LIST (gxml_element_list_get_type ())
#define GXML_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_ELEMENT_LIST, GXmlElementList))
#define GXML_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_ELEMENT_LIST, GXmlElementListClass))
#define GXML_IS_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_ELEMENT_LIST))
#define GXML_IS_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_ELEMENT_LIST))
#define GXML_ELEMENT_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_ELEMENT_LIST, GXmlElementListClass))

typedef struct _GXmlElementList GXmlElementList;
typedef struct _GXmlElementListClass GXmlElementListClass;

#define GXML_TYPE_NAMESPACE (gxml_namespace_get_type ())
#define GXML_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NAMESPACE, GXmlNamespace))
#define GXML_IS_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NAMESPACE))
#define GXML_NAMESPACE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_NAMESPACE, GXmlNamespaceIface))

typedef struct _GXmlNamespace GXmlNamespace;
typedef struct _GXmlNamespaceIface GXmlNamespaceIface;
typedef enum  {
	GXML_NODE_TYPE_INVALID = 0,
	GXML_NODE_TYPE_ELEMENT = 1,
	GXML_NODE_TYPE_ATTRIBUTE,
	GXML_NODE_TYPE_TEXT,
	GXML_NODE_TYPE_CDATA_SECTION,
	GXML_NODE_TYPE_ENTITY_REFERENCE,
	GXML_NODE_TYPE_ENTITY,
	GXML_NODE_TYPE_PROCESSING_INSTRUCTION,
	GXML_NODE_TYPE_COMMENT,
	GXML_NODE_TYPE_DOCUMENT,
	GXML_NODE_TYPE_DOCUMENT_TYPE,
	GXML_NODE_TYPE_DOCUMENT_FRAGMENT,
	GXML_NODE_TYPE_NOTATION
} GXmlNodeType;

#define GXML_TYPE_NODE_TYPE (gxml_node_type_get_type ())
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _GxmlParserWriteFileAsyncData GxmlParserWriteFileAsyncData;
typedef struct _GxmlParserReadFileAsyncData GxmlParserReadFileAsyncData;
typedef struct _GxmlParserReadChildNodesAsyncData GxmlParserReadChildNodesAsyncData;

#define GXML_TYPE_GOM_OBJECT (gxml_gom_object_get_type ())
#define GXML_GOM_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_OBJECT, GXmlGomObject))
#define GXML_IS_GOM_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_OBJECT))
#define GXML_GOM_OBJECT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_GOM_OBJECT, GXmlGomObjectIface))

typedef struct _GXmlGomObject GXmlGomObject;
typedef struct _GXmlGomObjectIface GXmlGomObjectIface;

#define GXML_TYPE_GOM_PROPERTY (gxml_gom_property_get_type ())
#define GXML_GOM_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_PROPERTY, GXmlGomProperty))
#define GXML_IS_GOM_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_PROPERTY))
#define GXML_GOM_PROPERTY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_GOM_PROPERTY, GXmlGomPropertyIface))

typedef struct _GXmlGomProperty GXmlGomProperty;
typedef struct _GXmlGomPropertyIface GXmlGomPropertyIface;

#define GXML_TYPE_COLLECTION (gxml_collection_get_type ())
#define GXML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_COLLECTION, GXmlCollection))
#define GXML_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_COLLECTION))
#define GXML_COLLECTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_COLLECTION, GXmlCollectionIface))

typedef struct _GXmlCollection GXmlCollection;
typedef struct _GXmlCollectionIface GXmlCollectionIface;
#define _g_param_spec_unref0(var) ((var == NULL) ? NULL : (var = (g_param_spec_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define GXML_TYPE_GOM_NODE (gxml_gom_node_get_type ())
#define GXML_GOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_NODE, GXmlGomNode))
#define GXML_GOM_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_NODE, GXmlGomNodeClass))
#define GXML_IS_GOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_NODE))
#define GXML_IS_GOM_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_NODE))
#define GXML_GOM_NODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_NODE, GXmlGomNodeClass))

typedef struct _GXmlGomNode GXmlGomNode;
typedef struct _GXmlGomNodeClass GXmlGomNodeClass;

#define GXML_TYPE_GOM_ELEMENT (gxml_gom_element_get_type ())
#define GXML_GOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_ELEMENT, GXmlGomElement))
#define GXML_GOM_ELEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_ELEMENT, GXmlGomElementClass))
#define GXML_IS_GOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_ELEMENT))
#define GXML_IS_GOM_ELEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_ELEMENT))
#define GXML_GOM_ELEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_ELEMENT, GXmlGomElementClass))

typedef struct _GXmlGomElement GXmlGomElement;
typedef struct _GXmlGomElementClass GXmlGomElementClass;

/**
 * Parser Error codes for {@link DomNode} parsing objects
 */
typedef enum  {
	GXML_PARSER_ERROR_INVALID_DATA_ERROR,
	GXML_PARSER_ERROR_INVALID_FILE_ERROR,
	GXML_PARSER_ERROR_INVALID_STREAM_ERROR
} GXmlParserError;
#define GXML_PARSER_ERROR gxml_parser_error_quark ()
struct _GXmlDomEventIface {
	GTypeInterface parent_iface;
	void (*stop_propagation) (GXmlDomEvent* self);
	void (*stop_immediate_propagation) (GXmlDomEvent* self);
	void (*prevent_default) (GXmlDomEvent* self);
	void (*init_event) (GXmlDomEvent* self, const gchar* type, gboolean bubbles, gboolean cancelable);
	const gchar* (*get_etype) (GXmlDomEvent* self);
	GXmlDomEventTarget* (*get_event_target) (GXmlDomEvent* self);
	GXmlDomEventTarget* (*get_current_target) (GXmlDomEvent* self);
	gboolean (*get_bubbles) (GXmlDomEvent* self);
	gboolean (*get_cancelable) (GXmlDomEvent* self);
	gboolean (*get_is_trusted) (GXmlDomEvent* self);
	GXmlDomTimeStamp* (*get_time_stamp) (GXmlDomEvent* self);
	gboolean (*get_default_prevented) (GXmlDomEvent* self);
	GXmlDomEventPhase (*get_event_phase) (GXmlDomEvent* self);
};

struct _GXmlDomEventListenerIface {
	GTypeInterface parent_iface;
	void (*handle_event) (GXmlDomEventListener* self, GXmlDomEvent* event);
};

struct _GXmlDomEventTargetIface {
	GTypeInterface parent_iface;
	void (*add_event_listener) (GXmlDomEventTarget* self, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
	void (*remove_event_listener) (GXmlDomEventTarget* self, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
	gboolean (*dispatch_event) (GXmlDomEventTarget* self, GXmlDomEvent* event, GError** error);
};

struct _GXmlDomChildNodeIface {
	GTypeInterface parent_iface;
	void (*remove) (GXmlDomChildNode* self);
};

struct _GXmlDomNonDocumentTypeChildNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_previous_element_sibling) (GXmlDomNonDocumentTypeChildNode* self);
	GXmlDomElement* (*get_next_element_sibling) (GXmlDomNonDocumentTypeChildNode* self);
};

struct _GXmlDomHTMLCollectionIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_element) (GXmlDomHTMLCollection* self, gint index);
	GXmlDomElement** (*to_array) (GXmlDomHTMLCollection* self, gint* result_length1);
	GXmlDomElement* (*item) (GXmlDomHTMLCollection* self, gint index);
	GXmlDomElement* (*named_item) (GXmlDomHTMLCollection* self, const gchar* name);
	gint (*get_length) (GXmlDomHTMLCollection* self);
};

struct _GXmlDomTokenListIface {
	GTypeInterface parent_iface;
	gchar* (*item) (GXmlDomTokenList* self, gint index);
	gboolean (*contains) (GXmlDomTokenList* self, const gchar* token, GError** error);
	void (*add) (GXmlDomTokenList* self, gchar** tokens, gint tokens_length1, GError** error);
	void (*remove) (GXmlDomTokenList* self, gchar** tokens, gint tokens_length1);
	gboolean (*toggle) (GXmlDomTokenList* self, const gchar* token, gboolean force, gboolean _auto_, GError** error);
	gchar* (*to_string) (GXmlDomTokenList* self);
	gint (*get_length) (GXmlDomTokenList* self);
};

struct _GXmlDomNamedNodeMapIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*item) (GXmlDomNamedNodeMap* self, gint index);
	GXmlDomNode* (*get_named_item) (GXmlDomNamedNodeMap* self, const gchar* name);
	GXmlDomNode* (*set_named_item) (GXmlDomNamedNodeMap* self, GXmlDomNode* node, GError** error);
	GXmlDomNode* (*remove_named_item) (GXmlDomNamedNodeMap* self, const gchar* name, GError** error);
	GXmlDomNode* (*remove_named_item_ns) (GXmlDomNamedNodeMap* self, const gchar* namespace_uri, const gchar* localName, GError** error);
	GXmlDomNode* (*get_named_item_ns) (GXmlDomNamedNodeMap* self, const gchar* namespace_uri, const gchar* local_name, GError** error);
	GXmlDomNode* (*set_named_item_ns) (GXmlDomNamedNodeMap* self, GXmlDomNode* node, GError** error);
	gint (*get_length) (GXmlDomNamedNodeMap* self);
};

struct _GXmlDomElementIface {
	GTypeInterface parent_iface;
	gchar* (*get_attribute) (GXmlDomElement* self, const gchar* name);
	gchar* (*get_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	void (*set_attribute) (GXmlDomElement* self, const gchar* name, const gchar* value, GError** error);
	void (*set_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* name, const gchar* value, GError** error);
	void (*remove_attribute) (GXmlDomElement* self, const gchar* name);
	void (*remove_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	gboolean (*has_attribute) (GXmlDomElement* self, const gchar* name);
	gboolean (*has_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name) (GXmlDomElement* self, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_class_name) (GXmlDomElement* self, const gchar* class_names);
	gboolean (*matches) (GXmlDomElement* self, const gchar* selectors, GError** error);
	void (*read_from_uri) (GXmlDomElement* self, const gchar* uri, GError** error);
	void (*read_from_uri_async) (GXmlDomElement* self, const gchar* uri, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_from_uri_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	void (*read_from_file) (GXmlDomElement* self, GFile* f, GCancellable* cancellable, GError** error);
	void (*read_from_file_async) (GXmlDomElement* self, GFile* f, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_from_file_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	void (*read_from_stream) (GXmlDomElement* self, GInputStream* istream, GCancellable* cancellable, GError** error);
	void (*read_from_stream_async) (GXmlDomElement* self, GInputStream* istream, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_from_stream_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	void (*read_from_string) (GXmlDomElement* self, const gchar* str, GCancellable* cancellable, GError** error);
	void (*read_from_string_async) (GXmlDomElement* self, const gchar* str, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_from_string_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	gchar* (*write_string) (GXmlDomElement* self, GCancellable* cancellable, GError** error);
	void (*write_string_async) (GXmlDomElement* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gchar* (*write_string_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	void (*write_file) (GXmlDomElement* self, GFile* f, GCancellable* cancellable, GError** error);
	void (*write_file_async) (GXmlDomElement* self, GFile* f, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*write_file_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	void (*write_stream) (GXmlDomElement* self, GOutputStream* stream, GError** error);
	void (*write_stream_async) (GXmlDomElement* self, GOutputStream* stream, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*write_stream_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	GInputStream* (*create_stream) (GXmlDomElement* self, GError** error);
	void (*create_stream_async) (GXmlDomElement* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GInputStream* (*create_stream_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	gchar* (*get_namespace_uri) (GXmlDomElement* self);
	gchar* (*get_prefix) (GXmlDomElement* self);
	gchar* (*get_local_name) (GXmlDomElement* self);
	gchar* (*get_tag_name) (GXmlDomElement* self);
	gchar* (*get_id) (GXmlDomElement* self);
	void (*set_id) (GXmlDomElement* self, const gchar* value);
	gchar* (*get_class_name) (GXmlDomElement* self);
	void (*set_class_name) (GXmlDomElement* self, const gchar* value);
	GXmlDomTokenList* (*get_class_list) (GXmlDomElement* self);
	GXmlDomNamedNodeMap* (*get_attributes) (GXmlDomElement* self);
};

struct _GXmlDomNodeListIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*item) (GXmlDomNodeList* self, gint index);
	gint (*get_length) (GXmlDomNodeList* self);
};

struct _GXmlDomParentNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*query_selector) (GXmlDomParentNode* self, const gchar* selectors, GError** error);
	GXmlDomNodeList* (*query_selector_all) (GXmlDomParentNode* self, const gchar* selectors, GError** error);
	GXmlDomElementList* (*get_elements_by_property_value) (GXmlDomParentNode* self, const gchar* property, const gchar* value);
	GXmlDomHTMLCollection* (*get_children) (GXmlDomParentNode* self);
	GXmlDomElement* (*get_first_element_child) (GXmlDomParentNode* self);
	GXmlDomElement* (*get_last_element_child) (GXmlDomParentNode* self);
	gint (*get_child_element_count) (GXmlDomParentNode* self);
};

struct _GXmlDomNonElementParentNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_element_by_id) (GXmlDomNonElementParentNode* self, const gchar* element_id, GError** error);
};

struct _GXmlDomDocumentFragmentIface {
	GTypeInterface parent_iface;
};

struct _GXmlDomCharacterDataIface {
	GTypeInterface parent_iface;
	gchar* (*substring_data) (GXmlDomCharacterData* self, gint offset, gint count, GError** error);
	void (*append_data) (GXmlDomCharacterData* self, const gchar* data);
	void (*insert_data) (GXmlDomCharacterData* self, gint offset, const gchar* data, GError** error);
	void (*delete_data) (GXmlDomCharacterData* self, gint offset, gint count, GError** error);
	void (*replace_data) (GXmlDomCharacterData* self, gint offset, gint count, const gchar* data, GError** error);
	gchar* (*get_data) (GXmlDomCharacterData* self);
	void (*set_data) (GXmlDomCharacterData* self, const gchar* value);
	gint (*get_length) (GXmlDomCharacterData* self);
};

struct _GXmlDomTextIface {
	GTypeInterface parent_iface;
	GXmlDomText* (*split_text) (GXmlDomText* self, gint offset, GError** error);
	gchar* (*get_whole_text) (GXmlDomText* self);
};

struct _GXmlDomCommentIface {
	GTypeInterface parent_iface;
};

struct _GXmlDomProcessingInstructionIface {
	GTypeInterface parent_iface;
	gchar* (*get_target) (GXmlDomProcessingInstruction* self);
};

struct _GXmlDomRangeIface {
	GTypeInterface parent_iface;
	void (*set_start) (GXmlDomRange* self, GXmlDomNode* node, gint offset, GError** error);
	void (*set_end) (GXmlDomRange* self, GXmlDomNode* node, gint offset, GError** error);
	void (*set_start_before) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_start_after) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_end_before) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_end_after) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*collapse) (GXmlDomRange* self, gboolean to_start, GError** error);
	void (*select_node) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*select_node_contents) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	gint (*compare_boundary_points) (GXmlDomRange* self, GXmlDomRangeBoundaryPoints how, GXmlDomRange* sourceRange, GError** error);
	void (*delete_contents) (GXmlDomRange* self, GError** error);
	GXmlDomDocumentFragment* (*extract_contents) (GXmlDomRange* self, GError** error);
	GXmlDomDocumentFragment* (*clone_contents) (GXmlDomRange* self, GError** error);
	void (*insert_node) (GXmlDomRange* self, GXmlDomNode* node);
	void (*surround_contents) (GXmlDomRange* self, GXmlDomNode* newParent);
	GXmlDomRange* (*clone_range) (GXmlDomRange* self);
	void (*detach) (GXmlDomRange* self);
	gboolean (*is_point_in_range) (GXmlDomRange* self, GXmlDomNode* node, gint offset);
	gshort (*compare_point) (GXmlDomRange* self, GXmlDomNode* node, gint offset);
	gboolean (*intersects_node) (GXmlDomRange* self, GXmlDomNode* node);
	gchar* (*to_string) (GXmlDomRange* self);
	GXmlDomNode* (*get_start_container) (GXmlDomRange* self);
	gint (*get_start_offset) (GXmlDomRange* self);
	GXmlDomNode* (*get_end_container) (GXmlDomRange* self);
	gint (*get_end_offset) (GXmlDomRange* self);
	gboolean (*get_collapsed) (GXmlDomRange* self);
	GXmlDomNode* (*get_common_ancestor_container) (GXmlDomRange* self);
};

struct _GXmlDomNodeIteratorIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*next_node) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*previous_node) (GXmlDomNodeIterator* self);
	void (*detach) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*get_root) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*get_reference_node) (GXmlDomNodeIterator* self);
	gboolean (*get_pointer_before_reference_node) (GXmlDomNodeIterator* self);
	gint (*get_what_to_show) (GXmlDomNodeIterator* self);
	GXmlDomNodeFilter* (*get_filter) (GXmlDomNodeIterator* self);
};

struct _GXmlDomTreeWalkerIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*parent_node) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*first_child) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*last_child) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*previous_sibling) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*next_sibling) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*previous_node) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*next_node) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*get_root) (GXmlDomTreeWalker* self);
	gint (*get_what_to_show) (GXmlDomTreeWalker* self);
	GXmlDomNodeFilter* (*get_filter) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*get_current_node) (GXmlDomTreeWalker* self);
};

struct _GXmlDomDocumentTypeIface {
	GTypeInterface parent_iface;
	const gchar* (*get_name) (GXmlDomDocumentType* self);
	const gchar* (*get_public_id) (GXmlDomDocumentType* self);
	const gchar* (*get_system_id) (GXmlDomDocumentType* self);
};

struct _GXmlDomXMLDocumentIface {
	GTypeInterface parent_iface;
};

struct _GXmlNamespaceIface {
	GTypeInterface parent_iface;
	gchar* (*get_uri) (GXmlNamespace* self);
	gchar* (*get_prefix) (GXmlNamespace* self);
};

struct _GXmlNodeIface {
	GTypeInterface parent_iface;
	GXmlNode* (*get) (GXmlNode* self, const gchar* key);
	GXmlElementList* (*get_elements_by_property_value) (GXmlNode* self, const gchar* property, const gchar* value);
	GXmlElementList* (*get_elements_by_name) (GXmlNode* self, const gchar* name);
	GXmlElementList* (*get_elements_by_name_ns) (GXmlNode* self, const gchar* name, const gchar* ns);
	gchar* (*to_string) (GXmlNode* self);
	gboolean (*set_namespace) (GXmlNode* self, const gchar* uri, const gchar* prefix);
	gchar* (*ns_prefix) (GXmlNode* self);
	gchar* (*ns_uri) (GXmlNode* self);
	GeeList* (*get_namespaces) (GXmlNode* self);
	GeeBidirList* (*get_children_nodes) (GXmlNode* self);
	GeeMap* (*get_attrs) (GXmlNode* self);
	gchar* (*get_name) (GXmlNode* self);
	gchar* (*get_value) (GXmlNode* self);
	void (*set_value) (GXmlNode* self, const gchar* value);
	GXmlNodeType (*get_type_node) (GXmlNode* self);
	GXmlDocument* (*get_document) (GXmlNode* self);
	GXmlNode* (*get_parent) (GXmlNode* self);
};

struct _GXmlDocumentIface {
	GTypeInterface parent_iface;
	GXmlNode* (*create_element) (GXmlDocument* self, const gchar* name, GError** error);
	GXmlNode* (*create_text) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_comment) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_cdata) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_pi) (GXmlDocument* self, const gchar* target, const gchar* data);
	gboolean (*save) (GXmlDocument* self, GCancellable* cancellable, GError** error);
	gboolean (*save_as) (GXmlDocument* self, GFile* f, GCancellable* cancellable, GError** error);
	gboolean (*get_indent) (GXmlDocument* self);
	void (*set_indent) (GXmlDocument* self, gboolean value);
	gboolean (*get_ns_top) (GXmlDocument* self);
	void (*set_ns_top) (GXmlDocument* self, gboolean value);
	gboolean (*get_prefix_default_ns) (GXmlDocument* self);
	void (*set_prefix_default_ns) (GXmlDocument* self, gboolean value);
	gboolean (*get_backup) (GXmlDocument* self);
	void (*set_backup) (GXmlDocument* self, gboolean value);
	GXmlNode* (*get_root) (GXmlDocument* self);
	GFile* (*get_file) (GXmlDocument* self);
	void (*set_file) (GXmlDocument* self, GFile* value);
};

struct _GXmlDomImplementationIface {
	GTypeInterface parent_iface;
	GXmlDomDocumentType* (*create_document_type) (GXmlDomImplementation* self, const gchar* qualified_name, const gchar* public_id, const gchar* system_id, GError** error);
	GXmlDomXMLDocument* (*create_document) (GXmlDomImplementation* self, const gchar* nspace, const gchar* qualified_name, GXmlDomDocumentType* doctype, GError** error);
	GXmlDocument* (*create_html_document) (GXmlDomImplementation* self, const gchar* title);
	gboolean (*has_feature) (GXmlDomImplementation* self);
};

struct _GXmlDomDocumentIface {
	GTypeInterface parent_iface;
	GXmlDomHTMLCollection* (*get_elements_by_tag_name) (GXmlDomDocument* self, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name_ns) (GXmlDomDocument* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_class_name) (GXmlDomDocument* self, const gchar* classNames);
	GXmlDomElement* (*create_element) (GXmlDomDocument* self, const gchar* local_name, GError** error);
	GXmlDomElement* (*create_element_ns) (GXmlDomDocument* self, const gchar* namespace, const gchar* qualified_name, GError** error);
	GXmlDomDocumentFragment* (*create_document_fragment) (GXmlDomDocument* self);
	GXmlDomText* (*create_text_node) (GXmlDomDocument* self, const gchar* data, GError** error);
	GXmlDomComment* (*create_comment) (GXmlDomDocument* self, const gchar* data, GError** error);
	GXmlDomProcessingInstruction* (*create_processing_instruction) (GXmlDomDocument* self, const gchar* target, const gchar* data, GError** error);
	GXmlDomNode* (*import_node) (GXmlDomDocument* self, GXmlDomNode* node, gboolean deep, GError** error);
	GXmlDomNode* (*adopt_node) (GXmlDomDocument* self, GXmlDomNode* node, GError** error);
	GXmlDomEvent* (*create_event) (GXmlDomDocument* self, const gchar* interface, GError** error);
	GXmlDomRange* (*create_range) (GXmlDomDocument* self);
	GXmlDomNodeIterator* (*create_node_iterator) (GXmlDomDocument* self, GXmlDomNode* root, gint whatToShow, GXmlDomNodeFilter* filter);
	GXmlDomTreeWalker* (*create_tree_walker) (GXmlDomDocument* self, GXmlDomNode* root, gint what_to_show, GXmlDomNodeFilter* filter);
	void (*write_file) (GXmlDomDocument* self, GFile* file, GCancellable* cancellable, GError** error);
	void (*write_file_async) (GXmlDomDocument* self, GFile* file, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*write_file_finish) (GXmlDomDocument* self, GAsyncResult* _res_, GError** error);
	void (*write_stream) (GXmlDomDocument* self, GOutputStream* stream, GCancellable* cancellable, GError** error);
	void (*write_stream_async) (GXmlDomDocument* self, GOutputStream* stream, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*write_stream_finish) (GXmlDomDocument* self, GAsyncResult* _res_, GError** error);
	GInputStream* (*create_stream) (GXmlDomDocument* self, GError** error);
	void (*create_stream_async) (GXmlDomDocument* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GInputStream* (*create_stream_finish) (GXmlDomDocument* self, GAsyncResult* _res_, GError** error);
	gchar* (*write_string) (GXmlDomDocument* self, GCancellable* cancellable, GError** error);
	void (*write_string_async) (GXmlDomDocument* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gchar* (*write_string_finish) (GXmlDomDocument* self, GAsyncResult* _res_, GError** error);
	void (*read_from_file) (GXmlDomDocument* self, GFile* file, GCancellable* cancellable, GError** error);
	void (*read_from_file_async) (GXmlDomDocument* self, GFile* file, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_from_file_finish) (GXmlDomDocument* self, GAsyncResult* _res_, GError** error);
	void (*read_from_string) (GXmlDomDocument* self, const gchar* str, GCancellable* cancellable, GError** error);
	void (*read_from_string_async) (GXmlDomDocument* self, const gchar* str, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_from_string_finish) (GXmlDomDocument* self, GAsyncResult* _res_, GError** error);
	void (*read_from_stream) (GXmlDomDocument* self, GInputStream* stream, GCancellable* cancellable, GError** error);
	void (*read_from_stream_async) (GXmlDomDocument* self, GInputStream* stream, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_from_stream_finish) (GXmlDomDocument* self, GAsyncResult* _res_, GError** error);
	GXmlParser* (*get_xml_parser) (GXmlDomDocument* self);
	void (*set_xml_parser) (GXmlDomDocument* self, GXmlParser* parser);
	GXmlDomImplementation* (*get_implementation) (GXmlDomDocument* self);
	const gchar* (*get_url) (GXmlDomDocument* self);
	const gchar* (*get_document_uri) (GXmlDomDocument* self);
	const gchar* (*get_origin) (GXmlDomDocument* self);
	const gchar* (*get_compat_mode) (GXmlDomDocument* self);
	const gchar* (*get_character_set) (GXmlDomDocument* self);
	const gchar* (*get_content_type) (GXmlDomDocument* self);
	GXmlDomDocumentType* (*get_doctype) (GXmlDomDocument* self);
	GXmlDomElement* (*get_document_element) (GXmlDomDocument* self);
};

struct _GXmlDomNodeIface {
	GTypeInterface parent_iface;
	gboolean (*has_child_nodes) (GXmlDomNode* self);
	void (*normalize) (GXmlDomNode* self);
	gboolean (*is_equal_node) (GXmlDomNode* self, GXmlDomNode* node);
	GXmlDomNodeDocumentPosition (*compare_document_position) (GXmlDomNode* self, GXmlDomNode* other);
	gboolean (*contains) (GXmlDomNode* self, GXmlDomNode* other);
	gchar* (*lookup_prefix) (GXmlDomNode* self, const gchar* nspace);
	gchar* (*lookup_namespace_uri) (GXmlDomNode* self, const gchar* prefix);
	gboolean (*is_default_namespace) (GXmlDomNode* self, const gchar* nspace);
	GXmlDomNode* (*insert_before) (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*append_child) (GXmlDomNode* self, GXmlDomNode* node, GError** error);
	GXmlDomNode* (*replace_child) (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*remove_child) (GXmlDomNode* self, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*clone_node) (GXmlDomNode* self, gboolean deep, GError** error);
	GXmlDomNodeNodeType (*get_node_type) (GXmlDomNode* self);
	gchar* (*get_node_name) (GXmlDomNode* self);
	const gchar* (*get_base_uri) (GXmlDomNode* self);
	GXmlDomDocument* (*get_owner_document) (GXmlDomNode* self);
	void (*set_owner_document) (GXmlDomNode* self, GXmlDomDocument* value);
	GXmlDomNode* (*get_parent_node) (GXmlDomNode* self);
	GXmlDomElement* (*get_parent_element) (GXmlDomNode* self);
	GXmlDomNodeList* (*get_child_nodes) (GXmlDomNode* self);
	GXmlDomNode* (*get_first_child) (GXmlDomNode* self);
	GXmlDomNode* (*get_last_child) (GXmlDomNode* self);
	GXmlDomNode* (*get_previous_sibling) (GXmlDomNode* self);
	GXmlDomNode* (*get_next_sibling) (GXmlDomNode* self);
	gchar* (*get_node_value) (GXmlDomNode* self);
	void (*set_node_value) (GXmlDomNode* self, const gchar* value);
	gchar* (*get_text_content) (GXmlDomNode* self);
	void (*set_text_content) (GXmlDomNode* self, const gchar* value);
};

struct _GXmlParserIface {
	GTypeInterface parent_iface;
	void (*write_file) (GXmlParser* self, GFile* file, GError** error);
	void (*write_file_async) (GXmlParser* self, GFile* file, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*write_file_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	gchar* (*write_string) (GXmlParser* self, GError** error);
	void (*write_string_async) (GXmlParser* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gchar* (*write_string_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	void (*write_stream) (GXmlParser* self, GOutputStream* stream, GError** error);
	void (*write_stream_async) (GXmlParser* self, GOutputStream* stream, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*write_stream_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	void (*read_file) (GXmlParser* self, GFile* file, GError** error);
	void (*read_file_async) (GXmlParser* self, GFile* file, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_file_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	void (*read_stream) (GXmlParser* self, GInputStream* stream, GError** error);
	void (*read_stream_async) (GXmlParser* self, GInputStream* stream, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_stream_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	void (*read_string) (GXmlParser* self, const gchar* str, GError** error);
	void (*read_string_async) (GXmlParser* self, const gchar* str, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_string_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	GInputStream* (*create_stream) (GXmlParser* self, GError** error);
	void (*create_stream_async) (GXmlParser* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GInputStream* (*create_stream_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	void (*read_child_nodes) (GXmlParser* self, GXmlDomNode* parent, GError** error);
	void (*read_child_nodes_async) (GXmlParser* self, GXmlDomNode* parent, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_child_nodes_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	gboolean (*read_child_node) (GXmlParser* self, GXmlDomNode* parent, GError** error);
	gboolean (*read_child_element) (GXmlParser* self, GXmlDomNode* parent, GError** error);
	gboolean (*read_element_property) (GXmlParser* self, GXmlDomNode* parent, GXmlDomNode* * element, GError** error);
	gboolean (*add_element_collection) (GXmlParser* self, GXmlDomNode* parent, GXmlDomNode* * element, GError** error);
	void (*read_child_nodes_stream) (GXmlParser* self, GInputStream* istream, GError** error);
	void (*read_child_nodes_string) (GXmlParser* self, const gchar* str, GError** error);
	gchar* (*read_unparsed) (GXmlParser* self, GError** error);
	gboolean (*move_next_node) (GXmlParser* self, GError** error);
	gboolean (*current_is_empty_element) (GXmlParser* self);
	gboolean (*current_is_element) (GXmlParser* self);
	gboolean (*current_is_document) (GXmlParser* self);
	gchar* (*current_node_name) (GXmlParser* self);
	GXmlDomElement* (*create_element) (GXmlParser* self, GXmlDomNode* parent, GError** error);
	void (*read_element) (GXmlParser* self, GXmlDomElement* element, GError** error);
	gboolean (*get_backup) (GXmlParser* self);
	void (*set_backup) (GXmlParser* self, gboolean value);
	gboolean (*get_indent) (GXmlParser* self);
	void (*set_indent) (GXmlParser* self, gboolean value);
	GCancellable* (*get_cancellable) (GXmlParser* self);
	void (*set_cancellable) (GXmlParser* self, GCancellable* value);
	GXmlDomNode* (*get_node) (GXmlParser* self);
};

struct _GxmlParserWriteFileAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	GAsyncReadyCallback _callback_;
	gboolean _task_complete_;
	GXmlParser* self;
	GFile* file;
	GFileOutputStream* ostream;
	gboolean _tmp0_;
	gboolean _tmp1_;
	GCancellable* _tmp2_;
	GCancellable* _tmp3_;
	GFileOutputStream* _tmp4_;
	GFileOutputStream* _tmp5_;
	GError* _inner_error0_;
};

struct _GxmlParserReadFileAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	GAsyncReadyCallback _callback_;
	gboolean _task_complete_;
	GXmlParser* self;
	GFile* file;
	GError* _tmp0_;
	GFileInputStream* _tmp1_;
	GFileInputStream* _tmp2_;
	GError* _inner_error0_;
};

struct _GxmlParserReadChildNodesAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	GAsyncReadyCallback _callback_;
	gboolean _task_complete_;
	GXmlParser* self;
	GXmlDomNode* parent;
	gboolean cont;
	gboolean _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
	GError* _inner_error0_;
};

typedef enum  {
	GXML_DOM_ERROR_INDEX_SIZE_ERROR = 1,
	GXML_DOM_ERROR_DOMSTRING_SIZE_ERROR,
	GXML_DOM_ERROR_HIERARCHY_REQUEST_ERROR,
	GXML_DOM_ERROR_WRONG_DOCUMENT_ERROR,
	GXML_DOM_ERROR_INVALID_CHARACTER_ERROR,
	GXML_DOM_ERROR_NO_DATA_ALLOWED_ERROR,
	GXML_DOM_ERROR_NO_MODIFICATION_ALLOWED_ERROR,
	GXML_DOM_ERROR_NOT_FOUND_ERROR,
	GXML_DOM_ERROR_NOT_SUPPORTED_ERROR,
	GXML_DOM_ERROR_INUSE_ATTRIBUTE_ERROR,
	GXML_DOM_ERROR_INVALID_STATE_ERROR,
	GXML_DOM_ERROR_SYNTAX_ERROR,
	GXML_DOM_ERROR_INVALID_MODIFICATION_ERROR,
	GXML_DOM_ERROR_NAMESPACE_ERROR,
	GXML_DOM_ERROR_INVALID_ACCESS_ERROR,
	GXML_DOM_ERROR_VALIDATION_ERROR,
	GXML_DOM_ERROR_TYPE_MISMATCH_ERROR,
	GXML_DOM_ERROR_SECURITY_ERROR,
	GXML_DOM_ERROR_NETWORK_ERROR,
	GXML_DOM_ERROR_ABORT_ERROR,
	GXML_DOM_ERROR_URL_MISMATCH_ERROR,
	GXML_DOM_ERROR_QUOTA_EXCEEDED_ERROR,
	GXML_DOM_ERROR_TIME_OUT_ERROR,
	GXML_DOM_ERROR_INVALID_NODE_TYPE_ERROR,
	GXML_DOM_ERROR_DATA_CLONE_ERROR
} GXmlDomError;
#define GXML_DOM_ERROR gxml_dom_error_quark ()
struct _GXmlGomPropertyIface {
	GTypeInterface parent_iface;
	gboolean (*validate_value) (GXmlGomProperty* self, const gchar* val);
	gchar* (*get_value) (GXmlGomProperty* self);
	void (*set_value) (GXmlGomProperty* self, const gchar* value);
};

struct _GXmlGomObjectIface {
	GTypeInterface parent_iface;
	GList* (*get_properties_list) (GXmlGomObject* self);
	GParamSpec* (*find_property_name) (GXmlGomObject* self, const gchar* nick);
	GParamSpec* (*find_object_property_name) (GXmlGomObject* self, const gchar* pname);
	GList* (*get_property_element_list) (GXmlGomObject* self);
	gchar* (*get_property_string) (GXmlGomObject* self, GParamSpec* prop);
	gchar* (*get_attribute) (GXmlGomObject* self, const gchar* name);
	GXmlGomProperty* (*find_property) (GXmlGomObject* self, const gchar* name);
	gboolean (*set_attribute) (GXmlGomObject* self, const gchar* name, const gchar* val);
	GXmlDomElement* (*get_child) (GXmlGomObject* self, const gchar* name);
	GXmlDomElementList* (*find_elements) (GXmlGomObject* self, const gchar* name);
	gboolean (*remove_attribute) (GXmlGomObject* self, const gchar* name);
	gboolean (*set_instance_property) (GXmlGomObject* self, const gchar* name);
	void (*clean_property_elements) (GXmlGomObject* self, const gchar* name, GError** error);
};

struct _GXmlCollectionIface {
	GTypeInterface parent_iface;
	void (*search) (GXmlCollection* self, GError** error);
	GXmlDomElement* (*get_item) (GXmlCollection* self, gint index, GError** error);
	void (*append) (GXmlCollection* self, GXmlDomElement* node, GError** error);
	void (*initialize) (GXmlCollection* self, GType t, GError** error);
	GXmlDomElement* (*create_item) (GXmlCollection* self);
	gboolean (*validate_append) (GXmlCollection* self, gint index, GXmlDomElement* element, GError** error);
	void (*clear) (GXmlCollection* self, GError** error);
	GQueue* (*get_nodes_index) (GXmlCollection* self);
	GXmlDomElement* (*get_element) (GXmlCollection* self);
	void (*set_element) (GXmlCollection* self, GXmlDomElement* value);
	const gchar* (*get_items_name) (GXmlCollection* self);
	GType (*get_items_type) (GXmlCollection* self);
	void (*set_items_type) (GXmlCollection* self, GType value);
	gint (*get_length) (GXmlCollection* self);
};

GQuark gxml_parser_error_quark (void);
GType gxml_dom_time_stamp_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_phase_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_listener_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_target_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_document_position_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_node_type_get_type (void) G_GNUC_CONST;
GType gxml_dom_child_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_non_document_type_child_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_html_collection_get_type (void) G_GNUC_CONST;
GType gxml_dom_token_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_named_node_map_get_type (void) G_GNUC_CONST;
GType gxml_dom_element_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_element_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_parent_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_non_element_parent_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_fragment_get_type (void) G_GNUC_CONST;
GType gxml_dom_character_data_get_type (void) G_GNUC_CONST;
GType gxml_dom_text_get_type (void) G_GNUC_CONST;
GType gxml_dom_comment_get_type (void) G_GNUC_CONST;
GType gxml_dom_processing_instruction_get_type (void) G_GNUC_CONST;
GType gxml_dom_range_boundary_points_get_type (void) G_GNUC_CONST;
GType gxml_dom_range_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_filter_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_iterator_get_type (void) G_GNUC_CONST;
GType gxml_dom_tree_walker_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_type_get_type (void) G_GNUC_CONST;
GType gxml_dom_xml_document_get_type (void) G_GNUC_CONST;
GType gxml_element_list_get_type (void) G_GNUC_CONST;
GType gxml_namespace_get_type (void) G_GNUC_CONST;
GType gxml_node_type_get_type (void) G_GNUC_CONST;
GType gxml_node_get_type (void) G_GNUC_CONST;
GType gxml_document_get_type (void) G_GNUC_CONST;
GType gxml_dom_implementation_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_get_type (void) G_GNUC_CONST;
GType gxml_parser_get_type (void) G_GNUC_CONST;
void gxml_parser_write_file (GXmlParser* self,
                             GFile* file,
                             GError** error);
static void gxml_parser_real_write_file (GXmlParser* self,
                                  GFile* file,
                                  GError** error);
gboolean gxml_parser_get_backup (GXmlParser* self);
GCancellable* gxml_parser_get_cancellable (GXmlParser* self);
void gxml_parser_write_stream (GXmlParser* self,
                               GOutputStream* stream,
                               GError** error);
static void gxml_parser_real_write_file_async_data_free (gpointer _data);
static void gxml_parser_real_write_file_async_async_ready_wrapper (GObject *source_object,
                                                            GAsyncResult *res,
                                                            void *user_data);
static void gxml_parser_real_write_file_async (GXmlParser* self,
                                        GFile* file,
                                        GAsyncReadyCallback _callback_,
                                        gpointer _user_data_);
void gxml_parser_write_file_async (GXmlParser* self,
                                   GFile* file,
                                   GAsyncReadyCallback _callback_,
                                   gpointer _user_data_);
void gxml_parser_write_file_finish (GXmlParser* self,
                                    GAsyncResult* _res_,
                                    GError** error);
static gboolean gxml_parser_real_write_file_async_co (GxmlParserWriteFileAsyncData* _data_);
static void gxml_parser_write_file_async_ready (GObject* source_object,
                                         GAsyncResult* _res_,
                                         gpointer _user_data_);
void gxml_parser_write_stream_async (GXmlParser* self,
                                     GOutputStream* stream,
                                     GAsyncReadyCallback _callback_,
                                     gpointer _user_data_);
void gxml_parser_write_stream_finish (GXmlParser* self,
                                      GAsyncResult* _res_,
                                      GError** error);
gchar* gxml_parser_write_string (GXmlParser* self,
                                 GError** error);
void gxml_parser_write_string_async (GXmlParser* self,
                                     GAsyncReadyCallback _callback_,
                                     gpointer _user_data_);
gchar* gxml_parser_write_string_finish (GXmlParser* self,
                                        GAsyncResult* _res_,
                                        GError** error);
void gxml_parser_read_file (GXmlParser* self,
                            GFile* file,
                            GError** error);
static void gxml_parser_real_read_file (GXmlParser* self,
                                 GFile* file,
                                 GError** error);
void gxml_parser_read_stream (GXmlParser* self,
                              GInputStream* stream,
                              GError** error);
static void gxml_parser_real_read_file_async_data_free (gpointer _data);
static void gxml_parser_real_read_file_async_async_ready_wrapper (GObject *source_object,
                                                           GAsyncResult *res,
                                                           void *user_data);
static void gxml_parser_real_read_file_async (GXmlParser* self,
                                       GFile* file,
                                       GAsyncReadyCallback _callback_,
                                       gpointer _user_data_);
void gxml_parser_read_file_async (GXmlParser* self,
                                  GFile* file,
                                  GAsyncReadyCallback _callback_,
                                  gpointer _user_data_);
void gxml_parser_read_file_finish (GXmlParser* self,
                                   GAsyncResult* _res_,
                                   GError** error);
static gboolean gxml_parser_real_read_file_async_co (GxmlParserReadFileAsyncData* _data_);
static gboolean _gxml_parser_real_read_file_async_co_gsource_func (gpointer self);
void gxml_parser_read_stream_async (GXmlParser* self,
                                    GInputStream* stream,
                                    GAsyncReadyCallback _callback_,
                                    gpointer _user_data_);
void gxml_parser_read_stream_finish (GXmlParser* self,
                                     GAsyncResult* _res_,
                                     GError** error);
static void gxml_parser_read_file_async_ready (GObject* source_object,
                                        GAsyncResult* _res_,
                                        gpointer _user_data_);
void gxml_parser_read_string (GXmlParser* self,
                              const gchar* str,
                              GError** error);
void gxml_parser_read_string_async (GXmlParser* self,
                                    const gchar* str,
                                    GAsyncReadyCallback _callback_,
                                    gpointer _user_data_);
void gxml_parser_read_string_finish (GXmlParser* self,
                                     GAsyncResult* _res_,
                                     GError** error);
GInputStream* gxml_parser_create_stream (GXmlParser* self,
                                         GError** error);
void gxml_parser_create_stream_async (GXmlParser* self,
                                      GAsyncReadyCallback _callback_,
                                      gpointer _user_data_);
GInputStream* gxml_parser_create_stream_finish (GXmlParser* self,
                                                GAsyncResult* _res_,
                                                GError** error);
void gxml_parser_read_child_nodes (GXmlParser* self,
                                   GXmlDomNode* parent,
                                   GError** error);
static void gxml_parser_real_read_child_nodes (GXmlParser* self,
                                        GXmlDomNode* parent,
                                        GError** error);
gboolean gxml_parser_read_child_node (GXmlParser* self,
                                      GXmlDomNode* parent,
                                      GError** error);
gboolean gxml_parser_move_next_node (GXmlParser* self,
                                     GError** error);
gboolean gxml_parser_current_is_element (GXmlParser* self);
gboolean gxml_parser_read_child_element (GXmlParser* self,
                                         GXmlDomNode* parent,
                                         GError** error);
static void gxml_parser_real_read_child_nodes_async_data_free (gpointer _data);
static void gxml_parser_real_read_child_nodes_async_async_ready_wrapper (GObject *source_object,
                                                                  GAsyncResult *res,
                                                                  void *user_data);
static void gxml_parser_real_read_child_nodes_async (GXmlParser* self,
                                              GXmlDomNode* parent,
                                              GAsyncReadyCallback _callback_,
                                              gpointer _user_data_);
void gxml_parser_read_child_nodes_async (GXmlParser* self,
                                         GXmlDomNode* parent,
                                         GAsyncReadyCallback _callback_,
                                         gpointer _user_data_);
void gxml_parser_read_child_nodes_finish (GXmlParser* self,
                                          GAsyncResult* _res_,
                                          GError** error);
static gboolean gxml_parser_real_read_child_nodes_async_co (GxmlParserReadChildNodesAsyncData* _data_);
static gboolean _gxml_parser_real_read_child_nodes_async_co_gsource_func (gpointer self);
static gboolean gxml_parser_real_read_child_element (GXmlParser* self,
                                              GXmlDomNode* parent,
                                              GError** error);
GQuark gxml_dom_error_quark (void);
gboolean gxml_parser_current_is_empty_element (GXmlParser* self);
gboolean gxml_parser_read_element_property (GXmlParser* self,
                                            GXmlDomNode* parent,
                                            GXmlDomNode* * element,
                                            GError** error);
gboolean gxml_parser_add_element_collection (GXmlParser* self,
                                             GXmlDomNode* parent,
                                             GXmlDomNode* * element,
                                             GError** error);
GXmlDomElement* gxml_parser_create_element (GXmlParser* self,
                                            GXmlDomNode* parent,
                                            GError** error);
void gxml_parser_read_element (GXmlParser* self,
                               GXmlDomElement* element,
                               GError** error);
static gboolean gxml_parser_real_read_element_property (GXmlParser* self,
                                                 GXmlDomNode* parent,
                                                 GXmlDomNode* * element,
                                                 GError** error);
GType gxml_gom_property_get_type (void) G_GNUC_CONST;
GType gxml_gom_object_get_type (void) G_GNUC_CONST;
GList* gxml_gom_object_get_property_element_list (GXmlGomObject* self);
GType gxml_collection_get_type (void) G_GNUC_CONST;
GXmlDomNode* gxml_parser_get_node (GXmlParser* self);
GXmlDomDocument* gxml_dom_node_get_owner_document (GXmlDomNode* self);
gchar* gxml_dom_element_get_local_name (GXmlDomElement* self);
gchar* gxml_parser_current_node_name (GXmlParser* self);
GXmlDomNode* gxml_dom_node_append_child (GXmlDomNode* self,
                                         GXmlDomNode* node,
                                         GError** error);
static void _g_param_spec_unref0_ (gpointer var);
static inline void _g_list_free__g_param_spec_unref0_ (GList* self);
static gboolean gxml_parser_real_add_element_collection (GXmlParser* self,
                                                  GXmlDomNode* parent,
                                                  GXmlDomNode* * element,
                                                  GError** error);
GType gxml_collection_get_items_type (GXmlCollection* self);
const gchar* gxml_collection_get_items_name (GXmlCollection* self);
GXmlDomElement* gxml_collection_get_element (GXmlCollection* self);
GType gxml_gom_node_get_type (void) G_GNUC_CONST;
GType gxml_gom_element_get_type (void) G_GNUC_CONST;
void gxml_collection_append (GXmlCollection* self,
                             GXmlDomElement* node,
                             GError** error);
void gxml_parser_read_child_nodes_stream (GXmlParser* self,
                                          GInputStream* istream,
                                          GError** error);
void gxml_parser_read_child_nodes_string (GXmlParser* self,
                                          const gchar* str,
                                          GError** error);
static void gxml_parser_real_read_child_nodes_string (GXmlParser* self,
                                               const gchar* str,
                                               GError** error);
static guint8* _vala_array_dup7 (guint8* self,
                          int length);
gchar* gxml_parser_read_unparsed (GXmlParser* self,
                                  GError** error);
gboolean gxml_parser_current_is_document (GXmlParser* self);
void gxml_parser_set_backup (GXmlParser* self,
                             gboolean value);
gboolean gxml_parser_get_indent (GXmlParser* self);
void gxml_parser_set_indent (GXmlParser* self,
                             gboolean value);
void gxml_parser_set_cancellable (GXmlParser* self,
                                  GCancellable* value);

GQuark
gxml_parser_error_quark (void)
{
	return g_quark_from_static_string ("gxml-parser-error-quark");
}

/**
   * Writes a {@link GXml.DomDocument} to a {@link GLib.File}
   */
static void
gxml_parser_real_write_file (GXmlParser* self,
                             GFile* file,
                             GError** error)
{
	GFileOutputStream* ostream = NULL;
	gboolean _tmp0_;
	gboolean _tmp1_;
	GCancellable* _tmp2_;
	GCancellable* _tmp3_;
	GFileOutputStream* _tmp4_;
	GFileOutputStream* _tmp5_;
	GError* _inner_error0_ = NULL;
	g_return_if_fail (file != NULL);
	_tmp0_ = gxml_parser_get_backup (self);
	_tmp1_ = _tmp0_;
	_tmp2_ = gxml_parser_get_cancellable (self);
	_tmp3_ = _tmp2_;
	_tmp4_ = g_file_replace (file, NULL, _tmp1_, G_FILE_CREATE_NONE, _tmp3_, &_inner_error0_);
	ostream = _tmp4_;
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		return;
	}
	_tmp5_ = ostream;
	gxml_parser_write_stream (self, (GOutputStream*) _tmp5_, &_inner_error0_);
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		_g_object_unref0 (ostream);
		return;
	}
	_g_object_unref0 (ostream);
}

void
gxml_parser_write_file (GXmlParser* self,
                        GFile* file,
                        GError** error)
{
	g_return_if_fail (self != NULL);
	GXML_PARSER_GET_INTERFACE (self)->write_file (self, file, error);
}

static void
gxml_parser_real_write_file_async_data_free (gpointer _data)
{
	GxmlParserWriteFileAsyncData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->file);
	_g_object_unref0 (_data_->self);
	g_slice_free (GxmlParserWriteFileAsyncData, _data_);
}

static void
gxml_parser_real_write_file_async_async_ready_wrapper (GObject *source_object,
                                                       GAsyncResult *res,
                                                       void *user_data)
{
	GxmlParserWriteFileAsyncData* _task_data_;
	_task_data_ = g_task_get_task_data (G_TASK (res));
	if (_task_data_->_callback_ != NULL) {
		_task_data_->_callback_ (source_object, res, user_data);
	}
	_task_data_->_task_complete_ = TRUE;
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
gxml_parser_real_write_file_async (GXmlParser* self,
                                   GFile* file,
                                   GAsyncReadyCallback _callback_,
                                   gpointer _user_data_)
{
	GxmlParserWriteFileAsyncData* _data_;
	GXmlParser* _tmp0_;
	GFile* _tmp1_;
	_data_ = g_slice_new0 (GxmlParserWriteFileAsyncData);
	_data_->_callback_ = _callback_;
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, gxml_parser_real_write_file_async_async_ready_wrapper, _user_data_);
	if (_callback_ == NULL) {
		_data_->_task_complete_ = TRUE;
	}
	g_task_set_task_data (_data_->_async_result, _data_, gxml_parser_real_write_file_async_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = _g_object_ref0 (file);
	_g_object_unref0 (_data_->file);
	_data_->file = _tmp1_;
	gxml_parser_real_write_file_async_co (_data_);
}

static void
gxml_parser_real_write_file_finish (GXmlParser* self,
                                    GAsyncResult* _res_,
                                    GError** error)
{
	GxmlParserWriteFileAsyncData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), error);
	if (NULL == _data_) {
		return;
	}
}

/**
   * Writes a {@link GXml.DomDocument} to a {@link GLib.File}
   */
static void
gxml_parser_write_file_async_ready (GObject* source_object,
                                    GAsyncResult* _res_,
                                    gpointer _user_data_)
{
	GxmlParserWriteFileAsyncData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	_data_->_task_complete_ = TRUE;
	gxml_parser_real_write_file_async_co (_data_);
}

static gboolean
gxml_parser_real_write_file_async_co (GxmlParserWriteFileAsyncData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		case 2:
		goto _state_2;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_tmp0_ = gxml_parser_get_backup (_data_->self);
	_data_->_tmp1_ = _data_->_tmp0_;
	_data_->_tmp2_ = gxml_parser_get_cancellable (_data_->self);
	_data_->_tmp3_ = _data_->_tmp2_;
	_data_->_state_ = 1;
	g_file_replace_async (_data_->file, NULL, _data_->_tmp1_, G_FILE_CREATE_NONE, 0, _data_->_tmp3_, gxml_parser_write_file_async_ready, _data_);
	return FALSE;
	_state_1:
	_data_->_tmp4_ = g_file_replace_finish (_data_->file, _data_->_res_, &_data_->_inner_error0_);
	_data_->ostream = _data_->_tmp4_;
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		g_task_return_error (_data_->_async_result, _data_->_inner_error0_);
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_data_->_tmp5_ = _data_->ostream;
	_data_->_state_ = 2;
	gxml_parser_write_stream_async (_data_->self, (GOutputStream*) _data_->_tmp5_, gxml_parser_write_file_async_ready, _data_);
	return FALSE;
	_state_2:
	gxml_parser_write_stream_finish (_data_->self, _data_->_res_, &_data_->_inner_error0_);
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		g_task_return_error (_data_->_async_result, _data_->_inner_error0_);
		_g_object_unref0 (_data_->ostream);
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_g_object_unref0 (_data_->ostream);
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!_data_->_task_complete_) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

void
gxml_parser_write_file_async (GXmlParser* self,
                              GFile* file,
                              GAsyncReadyCallback _callback_,
                              gpointer _user_data_)
{
	GXML_PARSER_GET_INTERFACE (self)->write_file_async (self, file, _callback_, _user_data_);
}

void
gxml_parser_write_file_finish (GXmlParser* self,
                               GAsyncResult* _res_,
                               GError** error)
{
	GXML_PARSER_GET_INTERFACE (self)->write_file_finish (self, _res_, error);
}

/**
   * Writes a {@link node} to a string
   */
gchar*
gxml_parser_write_string (GXmlParser* self,
                          GError** error)
{
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_PARSER_GET_INTERFACE (self)->write_string (self, error);
}

void
gxml_parser_write_string_async (GXmlParser* self,
                                GAsyncReadyCallback _callback_,
                                gpointer _user_data_)
{
	GXML_PARSER_GET_INTERFACE (self)->write_string_async (self, _callback_, _user_data_);
}

gchar*
gxml_parser_write_string_finish (GXmlParser* self,
                                 GAsyncResult* _res_,
                                 GError** error)
{
	return GXML_PARSER_GET_INTERFACE (self)->write_string_finish (self, _res_, error);
}

/**
   * Writes a {@link GXml.DomDocument} to a {@link GLib.OutputStream}
   */
void
gxml_parser_write_stream (GXmlParser* self,
                          GOutputStream* stream,
                          GError** error)
{
	g_return_if_fail (self != NULL);
	GXML_PARSER_GET_INTERFACE (self)->write_stream (self, stream, error);
}

void
gxml_parser_write_stream_async (GXmlParser* self,
                                GOutputStream* stream,
                                GAsyncReadyCallback _callback_,
                                gpointer _user_data_)
{
	GXML_PARSER_GET_INTERFACE (self)->write_stream_async (self, stream, _callback_, _user_data_);
}

void
gxml_parser_write_stream_finish (GXmlParser* self,
                                 GAsyncResult* _res_,
                                 GError** error)
{
	GXML_PARSER_GET_INTERFACE (self)->write_stream_finish (self, _res_, error);
}

/**
   * Reads a {@link node} from a {@link GLib.File}
   */
static void
gxml_parser_real_read_file (GXmlParser* self,
                            GFile* file,
                            GError** error)
{
	GFileInputStream* _tmp1_ = NULL;
	GFileInputStream* _tmp2_;
	GError* _inner_error0_ = NULL;
	g_return_if_fail (file != NULL);
	if (!g_file_query_exists (file, NULL)) {
		GError* _tmp0_;
		_tmp0_ = g_error_new_literal (GXML_PARSER_ERROR, GXML_PARSER_ERROR_INVALID_FILE_ERROR, _ ("File doesn't exist"));
		_inner_error0_ = _tmp0_;
		g_propagate_error (error, _inner_error0_);
		return;
	}
	_tmp2_ = g_file_read (file, NULL, &_inner_error0_);
	_tmp1_ = _tmp2_;
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		return;
	}
	gxml_parser_read_stream (self, (GInputStream*) _tmp1_, &_inner_error0_);
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		_g_object_unref0 (_tmp1_);
		return;
	}
	_g_object_unref0 (_tmp1_);
}

void
gxml_parser_read_file (GXmlParser* self,
                       GFile* file,
                       GError** error)
{
	g_return_if_fail (self != NULL);
	GXML_PARSER_GET_INTERFACE (self)->read_file (self, file, error);
}

static void
gxml_parser_real_read_file_async_data_free (gpointer _data)
{
	GxmlParserReadFileAsyncData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->file);
	_g_object_unref0 (_data_->self);
	g_slice_free (GxmlParserReadFileAsyncData, _data_);
}

static void
gxml_parser_real_read_file_async_async_ready_wrapper (GObject *source_object,
                                                      GAsyncResult *res,
                                                      void *user_data)
{
	GxmlParserReadFileAsyncData* _task_data_;
	_task_data_ = g_task_get_task_data (G_TASK (res));
	if (_task_data_->_callback_ != NULL) {
		_task_data_->_callback_ (source_object, res, user_data);
	}
	_task_data_->_task_complete_ = TRUE;
}

static void
gxml_parser_real_read_file_async (GXmlParser* self,
                                  GFile* file,
                                  GAsyncReadyCallback _callback_,
                                  gpointer _user_data_)
{
	GxmlParserReadFileAsyncData* _data_;
	GXmlParser* _tmp0_;
	GFile* _tmp1_;
	_data_ = g_slice_new0 (GxmlParserReadFileAsyncData);
	_data_->_callback_ = _callback_;
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, gxml_parser_real_read_file_async_async_ready_wrapper, _user_data_);
	if (_callback_ == NULL) {
		_data_->_task_complete_ = TRUE;
	}
	g_task_set_task_data (_data_->_async_result, _data_, gxml_parser_real_read_file_async_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = _g_object_ref0 (file);
	_g_object_unref0 (_data_->file);
	_data_->file = _tmp1_;
	gxml_parser_real_read_file_async_co (_data_);
}

static void
gxml_parser_real_read_file_finish (GXmlParser* self,
                                   GAsyncResult* _res_,
                                   GError** error)
{
	GxmlParserReadFileAsyncData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), error);
	if (NULL == _data_) {
		return;
	}
}

/**
   * Reads a {@link GXml.DomDocument} from a {@link GLib.File}
   */
static gboolean
_gxml_parser_real_read_file_async_co_gsource_func (gpointer self)
{
	gboolean result;
	result = gxml_parser_real_read_file_async_co (self);
	return result;
}

static void
gxml_parser_read_file_async_ready (GObject* source_object,
                                   GAsyncResult* _res_,
                                   gpointer _user_data_)
{
	GxmlParserReadFileAsyncData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	_data_->_task_complete_ = TRUE;
	gxml_parser_real_read_file_async_co (_data_);
}

static gboolean
gxml_parser_real_read_file_async_co (GxmlParserReadFileAsyncData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		case 2:
		goto _state_2;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	if (!g_file_query_exists (_data_->file, NULL)) {
		_data_->_tmp0_ = g_error_new_literal (GXML_PARSER_ERROR, GXML_PARSER_ERROR_INVALID_FILE_ERROR, _ ("File doesn't exist"));
		_data_->_inner_error0_ = _data_->_tmp0_;
		g_task_return_error (_data_->_async_result, _data_->_inner_error0_);
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, _gxml_parser_real_read_file_async_co_gsource_func, _data_, NULL);
	_data_->_state_ = 1;
	return FALSE;
	_state_1:
	;
	_data_->_tmp2_ = g_file_read (_data_->file, NULL, &_data_->_inner_error0_);
	_data_->_tmp1_ = _data_->_tmp2_;
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		g_task_return_error (_data_->_async_result, _data_->_inner_error0_);
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_data_->_state_ = 2;
	gxml_parser_read_stream_async (_data_->self, (GInputStream*) _data_->_tmp1_, gxml_parser_read_file_async_ready, _data_);
	return FALSE;
	_state_2:
	gxml_parser_read_stream_finish (_data_->self, _data_->_res_, &_data_->_inner_error0_);
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		g_task_return_error (_data_->_async_result, _data_->_inner_error0_);
		_g_object_unref0 (_data_->_tmp1_);
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_g_object_unref0 (_data_->_tmp1_);
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!_data_->_task_complete_) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

void
gxml_parser_read_file_async (GXmlParser* self,
                             GFile* file,
                             GAsyncReadyCallback _callback_,
                             gpointer _user_data_)
{
	GXML_PARSER_GET_INTERFACE (self)->read_file_async (self, file, _callback_, _user_data_);
}

void
gxml_parser_read_file_finish (GXmlParser* self,
                              GAsyncResult* _res_,
                              GError** error)
{
	GXML_PARSER_GET_INTERFACE (self)->read_file_finish (self, _res_, error);
}

/**
   * Read a {@link GXml.DomDocument} from a {@link GLib.InputStream}
   */
void
gxml_parser_read_stream (GXmlParser* self,
                         GInputStream* stream,
                         GError** error)
{
	g_return_if_fail (self != NULL);
	GXML_PARSER_GET_INTERFACE (self)->read_stream (self, stream, error);
}

void
gxml_parser_read_stream_async (GXmlParser* self,
                               GInputStream* stream,
                               GAsyncReadyCallback _callback_,
                               gpointer _user_data_)
{
	GXML_PARSER_GET_INTERFACE (self)->read_stream_async (self, stream, _callback_, _user_data_);
}

void
gxml_parser_read_stream_finish (GXmlParser* self,
                                GAsyncResult* _res_,
                                GError** error)
{
	GXML_PARSER_GET_INTERFACE (self)->read_stream_finish (self, _res_, error);
}

/**
   * Reads a {@link node} from a string
   */
void
gxml_parser_read_string (GXmlParser* self,
                         const gchar* str,
                         GError** error)
{
	g_return_if_fail (self != NULL);
	GXML_PARSER_GET_INTERFACE (self)->read_string (self, str, error);
}

void
gxml_parser_read_string_async (GXmlParser* self,
                               const gchar* str,
                               GAsyncReadyCallback _callback_,
                               gpointer _user_data_)
{
	GXML_PARSER_GET_INTERFACE (self)->read_string_async (self, str, _callback_, _user_data_);
}

void
gxml_parser_read_string_finish (GXmlParser* self,
                                GAsyncResult* _res_,
                                GError** error)
{
	GXML_PARSER_GET_INTERFACE (self)->read_string_finish (self, _res_, error);
}

/**
   * Creates an {@link GLib.InputStream} to write a string representation
   * in XML
   */
GInputStream*
gxml_parser_create_stream (GXmlParser* self,
                           GError** error)
{
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_PARSER_GET_INTERFACE (self)->create_stream (self, error);
}

void
gxml_parser_create_stream_async (GXmlParser* self,
                                 GAsyncReadyCallback _callback_,
                                 gpointer _user_data_)
{
	GXML_PARSER_GET_INTERFACE (self)->create_stream_async (self, _callback_, _user_data_);
}

GInputStream*
gxml_parser_create_stream_finish (GXmlParser* self,
                                  GAsyncResult* _res_,
                                  GError** error)
{
	return GXML_PARSER_GET_INTERFACE (self)->create_stream_finish (self, _res_, error);
}

/**
   * Iterates in all child nodes and append them to node.
   */
static void
gxml_parser_real_read_child_nodes (GXmlParser* self,
                                   GXmlDomNode* parent,
                                   GError** error)
{
	gboolean cont = FALSE;
	GError* _inner_error0_ = NULL;
	g_return_if_fail (parent != NULL);
	cont = TRUE;
	while (TRUE) {
		gboolean _tmp1_ = FALSE;
		if (!cont) {
			break;
		}
		if (G_TYPE_CHECK_INSTANCE_TYPE (parent, GXML_TYPE_DOM_DOCUMENT)) {
			gboolean _tmp0_ = FALSE;
			_tmp0_ = gxml_parser_read_child_node (self, parent, &_inner_error0_);
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
				g_propagate_error (error, _inner_error0_);
				return;
			}
			cont = _tmp0_;
		}
		_tmp1_ = gxml_parser_move_next_node (self, &_inner_error0_);
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			g_propagate_error (error, _inner_error0_);
			return;
		}
		if (!_tmp1_) {
			return;
		}
		if (gxml_parser_current_is_element (self)) {
			gboolean _tmp2_ = FALSE;
			_tmp2_ = gxml_parser_read_child_element (self, parent, &_inner_error0_);
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
				g_propagate_error (error, _inner_error0_);
				return;
			}
			cont = _tmp2_;
		} else {
			gboolean _tmp3_ = FALSE;
			_tmp3_ = gxml_parser_read_child_node (self, parent, &_inner_error0_);
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
				g_propagate_error (error, _inner_error0_);
				return;
			}
			cont = _tmp3_;
		}
	}
}

void
gxml_parser_read_child_nodes (GXmlParser* self,
                              GXmlDomNode* parent,
                              GError** error)
{
	g_return_if_fail (self != NULL);
	GXML_PARSER_GET_INTERFACE (self)->read_child_nodes (self, parent, error);
}

static void
gxml_parser_real_read_child_nodes_async_data_free (gpointer _data)
{
	GxmlParserReadChildNodesAsyncData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->parent);
	_g_object_unref0 (_data_->self);
	g_slice_free (GxmlParserReadChildNodesAsyncData, _data_);
}

static void
gxml_parser_real_read_child_nodes_async_async_ready_wrapper (GObject *source_object,
                                                             GAsyncResult *res,
                                                             void *user_data)
{
	GxmlParserReadChildNodesAsyncData* _task_data_;
	_task_data_ = g_task_get_task_data (G_TASK (res));
	if (_task_data_->_callback_ != NULL) {
		_task_data_->_callback_ (source_object, res, user_data);
	}
	_task_data_->_task_complete_ = TRUE;
}

static void
gxml_parser_real_read_child_nodes_async (GXmlParser* self,
                                         GXmlDomNode* parent,
                                         GAsyncReadyCallback _callback_,
                                         gpointer _user_data_)
{
	GxmlParserReadChildNodesAsyncData* _data_;
	GXmlParser* _tmp0_;
	GXmlDomNode* _tmp1_;
	_data_ = g_slice_new0 (GxmlParserReadChildNodesAsyncData);
	_data_->_callback_ = _callback_;
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, gxml_parser_real_read_child_nodes_async_async_ready_wrapper, _user_data_);
	if (_callback_ == NULL) {
		_data_->_task_complete_ = TRUE;
	}
	g_task_set_task_data (_data_->_async_result, _data_, gxml_parser_real_read_child_nodes_async_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = _g_object_ref0 (parent);
	_g_object_unref0 (_data_->parent);
	_data_->parent = _tmp1_;
	gxml_parser_real_read_child_nodes_async_co (_data_);
}

static void
gxml_parser_real_read_child_nodes_finish (GXmlParser* self,
                                          GAsyncResult* _res_,
                                          GError** error)
{
	GxmlParserReadChildNodesAsyncData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), error);
	if (NULL == _data_) {
		return;
	}
}

/**
   * Iterates in all child nodes and append them to node.
   */
static gboolean
_gxml_parser_real_read_child_nodes_async_co_gsource_func (gpointer self)
{
	gboolean result;
	result = gxml_parser_real_read_child_nodes_async_co (self);
	return result;
}

static gboolean
gxml_parser_real_read_child_nodes_async_co (GxmlParserReadChildNodesAsyncData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->cont = TRUE;
	while (TRUE) {
		if (!_data_->cont) {
			break;
		}
		g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, _gxml_parser_real_read_child_nodes_async_co_gsource_func, _data_, NULL);
		_data_->_state_ = 1;
		return FALSE;
		_state_1:
		;
		_data_->_tmp0_ = gxml_parser_move_next_node (_data_->self, &_data_->_inner_error0_);
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			g_task_return_error (_data_->_async_result, _data_->_inner_error0_);
			g_object_unref (_data_->_async_result);
			return FALSE;
		}
		if (!_data_->_tmp0_) {
			g_task_return_pointer (_data_->_async_result, _data_, NULL);
			if (_data_->_state_ != 0) {
				while (!_data_->_task_complete_) {
					g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
				}
			}
			g_object_unref (_data_->_async_result);
			return FALSE;
		}
		if (gxml_parser_current_is_element (_data_->self)) {
			_data_->_tmp1_ = gxml_parser_read_child_element (_data_->self, _data_->parent, &_data_->_inner_error0_);
			if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
				g_task_return_error (_data_->_async_result, _data_->_inner_error0_);
				g_object_unref (_data_->_async_result);
				return FALSE;
			}
			_data_->cont = _data_->_tmp1_;
		} else {
			_data_->_tmp2_ = gxml_parser_read_child_node (_data_->self, _data_->parent, &_data_->_inner_error0_);
			if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
				g_task_return_error (_data_->_async_result, _data_->_inner_error0_);
				g_object_unref (_data_->_async_result);
				return FALSE;
			}
			_data_->cont = _data_->_tmp2_;
		}
	}
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!_data_->_task_complete_) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

void
gxml_parser_read_child_nodes_async (GXmlParser* self,
                                    GXmlDomNode* parent,
                                    GAsyncReadyCallback _callback_,
                                    gpointer _user_data_)
{
	GXML_PARSER_GET_INTERFACE (self)->read_child_nodes_async (self, parent, _callback_, _user_data_);
}

void
gxml_parser_read_child_nodes_finish (GXmlParser* self,
                                     GAsyncResult* _res_,
                                     GError** error)
{
	GXML_PARSER_GET_INTERFACE (self)->read_child_nodes_finish (self, _res_, error);
}

/**
   * Creates a new {@link DomNode} and append it to
   * parent: depending on current node's type found by parser.
   *
   * If current found node is a {@link DomElement}, it is not parsed.
   * If you want to parse it use {@link read_element} method.
   *
   * Returns: true if node has been created and appended to parent.
   */
gboolean
gxml_parser_read_child_node (GXmlParser* self,
                             GXmlDomNode* parent,
                             GError** error)
{
	g_return_val_if_fail (self != NULL, FALSE);
	return GXML_PARSER_GET_INTERFACE (self)->read_child_node (self, parent, error);
}

/**
   * Reads current found element
   */
static gboolean
gxml_parser_real_read_child_element (GXmlParser* self,
                                     GXmlDomNode* parent,
                                     GError** error)
{
	gboolean result = FALSE;
	gboolean isempty = FALSE;
	GXmlDomNode* n = NULL;
	gboolean _tmp2_ = FALSE;
	GXmlDomNode* _tmp3_ = NULL;
	gboolean _tmp4_;
	GXmlDomNode* _tmp16_;
	GError* _inner_error0_ = NULL;
	g_return_val_if_fail (parent != NULL, FALSE);
	if (!gxml_parser_current_is_element (self)) {
		GError* _tmp0_;
		gboolean _tmp1_ = FALSE;
		_tmp0_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_INVALID_NODE_TYPE_ERROR, _ ("Invalid attempt to parse an element node, when current found node is n" \
"ot"));
		_inner_error0_ = _tmp0_;
		g_propagate_error (error, _inner_error0_);
		return _tmp1_;
	}
	isempty = gxml_parser_current_is_empty_element (self);
	n = NULL;
	_tmp4_ = gxml_parser_read_element_property (self, parent, &_tmp3_, &_inner_error0_);
	_g_object_unref0 (n);
	n = _tmp3_;
	_tmp2_ = _tmp4_;
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		gboolean _tmp5_ = FALSE;
		g_propagate_error (error, _inner_error0_);
		_g_object_unref0 (n);
		return _tmp5_;
	}
	if (!_tmp2_) {
		gboolean _tmp6_ = FALSE;
		GXmlDomNode* _tmp7_ = NULL;
		gboolean _tmp8_;
		_tmp8_ = gxml_parser_add_element_collection (self, parent, &_tmp7_, &_inner_error0_);
		_g_object_unref0 (n);
		n = _tmp7_;
		_tmp6_ = _tmp8_;
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			gboolean _tmp9_ = FALSE;
			g_propagate_error (error, _inner_error0_);
			_g_object_unref0 (n);
			return _tmp9_;
		}
		if (!_tmp6_) {
			GXmlDomElement* _tmp10_ = NULL;
			GXmlDomElement* _tmp11_;
			GXmlDomElement* _tmp13_;
			GXmlDomNode* _tmp14_;
			_tmp11_ = gxml_parser_create_element (self, parent, &_inner_error0_);
			_tmp10_ = _tmp11_;
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
				gboolean _tmp12_ = FALSE;
				g_propagate_error (error, _inner_error0_);
				_g_object_unref0 (n);
				return _tmp12_;
			}
			_tmp13_ = _tmp10_;
			_tmp10_ = NULL;
			_g_object_unref0 (n);
			n = (GXmlDomNode*) _tmp13_;
			_tmp14_ = n;
			gxml_parser_read_element (self, G_TYPE_CHECK_INSTANCE_TYPE (_tmp14_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp14_) : NULL, &_inner_error0_);
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
				gboolean _tmp15_ = FALSE;
				g_propagate_error (error, _inner_error0_);
				_g_object_unref0 (_tmp10_);
				_g_object_unref0 (n);
				return _tmp15_;
			}
			_g_object_unref0 (_tmp10_);
		}
	}
	_tmp16_ = n;
	if (_tmp16_ == NULL) {
		result = FALSE;
		_g_object_unref0 (n);
		return result;
	}
	if (!isempty) {
		GXmlDomNode* _tmp17_;
		_tmp17_ = n;
		gxml_parser_read_child_nodes (self, _tmp17_, &_inner_error0_);
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			gboolean _tmp18_ = FALSE;
			g_propagate_error (error, _inner_error0_);
			_g_object_unref0 (n);
			return _tmp18_;
		}
	}
	result = TRUE;
	_g_object_unref0 (n);
	return result;
}

gboolean
gxml_parser_read_child_element (GXmlParser* self,
                                GXmlDomNode* parent,
                                GError** error)
{
	g_return_val_if_fail (self != NULL, FALSE);
	return GXML_PARSER_GET_INTERFACE (self)->read_child_element (self, parent, error);
}

/**
   * Creates a new {@link DomElement} and append it as a child of parent: for current
   * read node, only if parent: have a property as {@link DomElement} type and current
   * node have same local name as property element.
   *
   * Returns: true if element is set to a new object and it is set as a child of parent:
   * as a property.
   */
static gpointer
_g_param_spec_ref0 (gpointer self)
{
	return self ? g_param_spec_ref (self) : NULL;
}

static void
_g_param_spec_unref0_ (gpointer var)
{
	(var == NULL) ? NULL : (var = (g_param_spec_unref (var), NULL));
}

static inline void
_g_list_free__g_param_spec_unref0_ (GList* self)
{
	g_list_free_full (self, (GDestroyNotify) _g_param_spec_unref0_);
}

static gboolean
gxml_parser_real_read_element_property (GXmlParser* self,
                                        GXmlDomNode* parent,
                                        GXmlDomNode* * element,
                                        GError** error)
{
	GXmlDomNode* _vala_element = NULL;
	gboolean result = FALSE;
	GList* _tmp0_;
	GError* _inner_error0_ = NULL;
	g_return_val_if_fail (parent != NULL, FALSE);
	_g_object_unref0 (_vala_element);
	_vala_element = NULL;
	if (!G_TYPE_CHECK_INSTANCE_TYPE (parent, GXML_TYPE_GOM_OBJECT)) {
		result = FALSE;
		if (element) {
			*element = _vala_element;
		} else {
			_g_object_unref0 (_vala_element);
		}
		return result;
	}
	_tmp0_ = gxml_gom_object_get_property_element_list (G_TYPE_CHECK_INSTANCE_TYPE (parent, GXML_TYPE_GOM_OBJECT) ? ((GXmlGomObject*) parent) : NULL);
	{
		GList* pspec_collection = NULL;
		GList* pspec_it = NULL;
		pspec_collection = _tmp0_;
		for (pspec_it = pspec_collection; pspec_it != NULL; pspec_it = pspec_it->next) {
			GParamSpec* _tmp1_;
			GParamSpec* pspec = NULL;
			_tmp1_ = _g_param_spec_ref0 ((GParamSpec*) pspec_it->data);
			pspec = _tmp1_;
			{
				GParamSpec* _tmp2_;
				GXmlDomElement* obj = NULL;
				GParamSpec* _tmp3_;
				GXmlDomNode* _tmp4_;
				GXmlDomNode* _tmp5_;
				GXmlDomDocument* _tmp6_;
				GXmlDomDocument* _tmp7_;
				GObject* _tmp8_;
				GObject* _tmp9_;
				GXmlDomElement* _tmp10_;
				GXmlDomElement* _tmp11_;
				gchar* _tmp12_;
				gchar* _tmp13_;
				gchar* _tmp14_;
				gchar* _tmp15_;
				gchar* _tmp16_;
				gchar* _tmp17_;
				gchar* _tmp18_;
				gchar* _tmp19_;
				gchar* _tmp20_;
				gboolean _tmp21_;
				_tmp2_ = pspec;
				if (g_type_is_a (_tmp2_->value_type, GXML_TYPE_COLLECTION)) {
					_g_param_spec_unref0 (pspec);
					continue;
				}
				_tmp3_ = pspec;
				_tmp4_ = gxml_parser_get_node (self);
				_tmp5_ = _tmp4_;
				_tmp6_ = gxml_dom_node_get_owner_document (_tmp5_);
				_tmp7_ = _tmp6_;
				_tmp8_ = g_object_new (_tmp3_->value_type, "owner-document", _tmp7_, NULL);
				_tmp9_ = G_IS_INITIALLY_UNOWNED (_tmp8_) ? g_object_ref_sink (_tmp8_) : _tmp8_;
				_tmp10_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp9_) : NULL;
				if (_tmp10_ == NULL) {
					_g_object_unref0 (_tmp9_);
				}
				obj = _tmp10_;
				_tmp11_ = obj;
				_tmp12_ = gxml_dom_element_get_local_name (_tmp11_);
				_tmp13_ = _tmp12_;
				_tmp14_ = _tmp13_;
				_tmp15_ = g_utf8_strdown (_tmp14_, (gssize) -1);
				_tmp16_ = _tmp15_;
				_tmp17_ = gxml_parser_current_node_name (self);
				_tmp18_ = _tmp17_;
				_tmp19_ = g_utf8_strdown (_tmp18_, (gssize) -1);
				_tmp20_ = _tmp19_;
				_tmp21_ = g_strcmp0 (_tmp16_, _tmp20_) == 0;
				_g_free0 (_tmp20_);
				_g_free0 (_tmp18_);
				_g_free0 (_tmp16_);
				_g_free0 (_tmp14_);
				if (_tmp21_) {
					GValue v = {0};
					GParamSpec* _tmp22_;
					GValue _tmp23_ = {0};
					GXmlDomElement* _tmp24_;
					GXmlDomNode* _tmp25_;
					GXmlDomNode* _tmp26_;
					GXmlDomElement* _tmp28_;
					GParamSpec* _tmp29_;
					const gchar* _tmp30_;
					GValue _tmp31_;
					GXmlDomElement* _tmp32_;
					GXmlDomElement* _tmp34_;
					GXmlDomNode* _tmp35_;
					_tmp22_ = pspec;
					g_value_init (&_tmp23_, _tmp22_->value_type);
					v = _tmp23_;
					_tmp24_ = obj;
					_tmp25_ = gxml_dom_node_append_child (parent, G_TYPE_CHECK_INSTANCE_TYPE (_tmp24_, GXML_TYPE_DOM_NODE) ? ((GXmlDomNode*) _tmp24_) : NULL, &_inner_error0_);
					_tmp26_ = _tmp25_;
					_g_object_unref0 (_tmp26_);
					if (G_UNLIKELY (_inner_error0_ != NULL)) {
						gboolean _tmp27_ = FALSE;
						g_propagate_error (error, _inner_error0_);
						G_IS_VALUE (&v) ? (g_value_unset (&v), NULL) : NULL;
						_g_object_unref0 (obj);
						_g_param_spec_unref0 (pspec);
						(pspec_collection == NULL) ? NULL : (pspec_collection = (_g_list_free__g_param_spec_unref0_ (pspec_collection), NULL));
						return _tmp27_;
					}
					_tmp28_ = obj;
					g_value_set_object (&v, (GObject*) _tmp28_);
					_tmp29_ = pspec;
					_tmp30_ = _tmp29_->name;
					_tmp31_ = v;
					g_object_set_property ((GObject*) parent, _tmp30_, &_tmp31_);
					_tmp32_ = obj;
					gxml_parser_read_element (self, G_TYPE_CHECK_INSTANCE_TYPE (_tmp32_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp32_) : NULL, &_inner_error0_);
					if (G_UNLIKELY (_inner_error0_ != NULL)) {
						gboolean _tmp33_ = FALSE;
						g_propagate_error (error, _inner_error0_);
						G_IS_VALUE (&v) ? (g_value_unset (&v), NULL) : NULL;
						_g_object_unref0 (obj);
						_g_param_spec_unref0 (pspec);
						(pspec_collection == NULL) ? NULL : (pspec_collection = (_g_list_free__g_param_spec_unref0_ (pspec_collection), NULL));
						return _tmp33_;
					}
					_tmp34_ = obj;
					_tmp35_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp34_, GXML_TYPE_DOM_NODE) ? ((GXmlDomNode*) _tmp34_) : NULL);
					_g_object_unref0 (_vala_element);
					_vala_element = _tmp35_;
					result = TRUE;
					G_IS_VALUE (&v) ? (g_value_unset (&v), NULL) : NULL;
					_g_object_unref0 (obj);
					_g_param_spec_unref0 (pspec);
					(pspec_collection == NULL) ? NULL : (pspec_collection = (_g_list_free__g_param_spec_unref0_ (pspec_collection), NULL));
					if (element) {
						*element = _vala_element;
					} else {
						_g_object_unref0 (_vala_element);
					}
					return result;
				}
				_g_object_unref0 (obj);
				_g_param_spec_unref0 (pspec);
			}
		}
		(pspec_collection == NULL) ? NULL : (pspec_collection = (_g_list_free__g_param_spec_unref0_ (pspec_collection), NULL));
	}
	result = FALSE;
	if (element) {
		*element = _vala_element;
	} else {
		_g_object_unref0 (_vala_element);
	}
	return result;
}

gboolean
gxml_parser_read_element_property (GXmlParser* self,
                                   GXmlDomNode* parent,
                                   GXmlDomNode* * element,
                                   GError** error)
{
	g_return_val_if_fail (self != NULL, FALSE);
	return GXML_PARSER_GET_INTERFACE (self)->read_element_property (self, parent, element, error);
}

/**
   * Creates a new {@link DomElement} and append it as a child of parent: for current
   * read node, only if parent: have a property as {@link Collection} type and current
   * node have same local name as collection {@link Collection.items_name}
   *
   * Returns: true if element is set to a new object, it is set as a child of parent:
   * and has been added to a parent:'s collection property.
   */
static gboolean
gxml_parser_real_add_element_collection (GXmlParser* self,
                                         GXmlDomNode* parent,
                                         GXmlDomNode* * element,
                                         GError** error)
{
	GXmlDomNode* _vala_element = NULL;
	gboolean result = FALSE;
	GList* _tmp0_;
	GError* _inner_error0_ = NULL;
	g_return_val_if_fail (parent != NULL, FALSE);
	_g_object_unref0 (_vala_element);
	_vala_element = NULL;
	if (!G_TYPE_CHECK_INSTANCE_TYPE (parent, GXML_TYPE_GOM_OBJECT)) {
		result = FALSE;
		if (element) {
			*element = _vala_element;
		} else {
			_g_object_unref0 (_vala_element);
		}
		return result;
	}
	_tmp0_ = gxml_gom_object_get_property_element_list (G_TYPE_CHECK_INSTANCE_TYPE (parent, GXML_TYPE_GOM_OBJECT) ? ((GXmlGomObject*) parent) : NULL);
	{
		GList* pspec_collection = NULL;
		GList* pspec_it = NULL;
		pspec_collection = _tmp0_;
		for (pspec_it = pspec_collection; pspec_it != NULL; pspec_it = pspec_it->next) {
			GParamSpec* _tmp1_;
			GParamSpec* pspec = NULL;
			_tmp1_ = _g_param_spec_ref0 ((GParamSpec*) pspec_it->data);
			pspec = _tmp1_;
			{
				GParamSpec* _tmp2_;
				GXmlCollection* col = NULL;
				GValue vc = {0};
				GParamSpec* _tmp3_;
				GValue _tmp4_ = {0};
				GParamSpec* _tmp5_;
				const gchar* _tmp6_;
				GObject* _tmp7_;
				GXmlCollection* _tmp8_;
				GXmlCollection* _tmp9_;
				gboolean _tmp18_ = FALSE;
				GXmlCollection* _tmp19_;
				GType _tmp20_;
				GType _tmp21_;
				gboolean _tmp27_ = FALSE;
				GXmlCollection* _tmp28_;
				const gchar* _tmp29_;
				const gchar* _tmp30_;
				gboolean _tmp36_ = FALSE;
				GXmlCollection* _tmp37_;
				GXmlDomElement* _tmp38_;
				GXmlDomElement* _tmp39_;
				GXmlCollection* _tmp45_;
				const gchar* _tmp46_;
				const gchar* _tmp47_;
				gchar* _tmp48_;
				gchar* _tmp49_;
				gchar* _tmp50_;
				gchar* _tmp51_;
				gchar* _tmp52_;
				gchar* _tmp53_;
				gboolean _tmp54_;
				_tmp2_ = pspec;
				if (!g_type_is_a (_tmp2_->value_type, GXML_TYPE_COLLECTION)) {
					_g_param_spec_unref0 (pspec);
					continue;
				}
				_tmp3_ = pspec;
				g_value_init (&_tmp4_, _tmp3_->value_type);
				vc = _tmp4_;
				_tmp5_ = pspec;
				_tmp6_ = _tmp5_->name;
				g_object_get_property ((GObject*) parent, _tmp6_, &vc);
				_tmp7_ = g_value_get_object (&vc);
				_tmp8_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, GXML_TYPE_COLLECTION) ? ((GXmlCollection*) _tmp7_) : NULL);
				_g_object_unref0 (col);
				col = _tmp8_;
				_tmp9_ = col;
				if (_tmp9_ == NULL) {
					GParamSpec* _tmp10_;
					GObject* _tmp11_;
					GObject* _tmp12_;
					GXmlCollection* _tmp13_;
					GXmlCollection* _tmp14_;
					GParamSpec* _tmp15_;
					const gchar* _tmp16_;
					GValue _tmp17_;
					_tmp10_ = pspec;
					_tmp11_ = g_object_new (_tmp10_->value_type, "element", parent, NULL);
					_tmp12_ = G_IS_INITIALLY_UNOWNED (_tmp11_) ? g_object_ref_sink (_tmp11_) : _tmp11_;
					_tmp13_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp12_, GXML_TYPE_COLLECTION) ? ((GXmlCollection*) _tmp12_) : NULL;
					if (_tmp13_ == NULL) {
						_g_object_unref0 (_tmp12_);
					}
					_g_object_unref0 (col);
					col = _tmp13_;
					_tmp14_ = col;
					g_value_set_object (&vc, (GObject*) _tmp14_);
					_tmp15_ = pspec;
					_tmp16_ = _tmp15_->name;
					_tmp17_ = vc;
					g_object_set_property ((GObject*) parent, _tmp16_, &_tmp17_);
				}
				_tmp19_ = col;
				_tmp20_ = gxml_collection_get_items_type (_tmp19_);
				_tmp21_ = _tmp20_;
				if (_tmp21_ == G_TYPE_INVALID) {
					_tmp18_ = TRUE;
				} else {
					GXmlCollection* _tmp22_;
					GType _tmp23_;
					GType _tmp24_;
					_tmp22_ = col;
					_tmp23_ = gxml_collection_get_items_type (_tmp22_);
					_tmp24_ = _tmp23_;
					_tmp18_ = !g_type_is_a (_tmp24_, GXML_TYPE_GOM_OBJECT);
				}
				if (_tmp18_) {
					GError* _tmp25_;
					gboolean _tmp26_ = FALSE;
					_tmp25_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_INVALID_NODE_TYPE_ERROR, _ ("Invalid object type set to Collection"));
					_inner_error0_ = _tmp25_;
					g_propagate_error (error, _inner_error0_);
					G_IS_VALUE (&vc) ? (g_value_unset (&vc), NULL) : NULL;
					_g_object_unref0 (col);
					_g_param_spec_unref0 (pspec);
					(pspec_collection == NULL) ? NULL : (pspec_collection = (_g_list_free__g_param_spec_unref0_ (pspec_collection), NULL));
					return _tmp26_;
				}
				_tmp28_ = col;
				_tmp29_ = gxml_collection_get_items_name (_tmp28_);
				_tmp30_ = _tmp29_;
				if (g_strcmp0 (_tmp30_, "") == 0) {
					_tmp27_ = TRUE;
				} else {
					GXmlCollection* _tmp31_;
					const gchar* _tmp32_;
					const gchar* _tmp33_;
					_tmp31_ = col;
					_tmp32_ = gxml_collection_get_items_name (_tmp31_);
					_tmp33_ = _tmp32_;
					_tmp27_ = _tmp33_ == NULL;
				}
				if (_tmp27_) {
					GError* _tmp34_;
					gboolean _tmp35_ = FALSE;
					_tmp34_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_INVALID_NODE_TYPE_ERROR, _ ("Invalid DomElement name for objects in Collection"));
					_inner_error0_ = _tmp34_;
					g_propagate_error (error, _inner_error0_);
					G_IS_VALUE (&vc) ? (g_value_unset (&vc), NULL) : NULL;
					_g_object_unref0 (col);
					_g_param_spec_unref0 (pspec);
					(pspec_collection == NULL) ? NULL : (pspec_collection = (_g_list_free__g_param_spec_unref0_ (pspec_collection), NULL));
					return _tmp35_;
				}
				_tmp37_ = col;
				_tmp38_ = gxml_collection_get_element (_tmp37_);
				_tmp39_ = _tmp38_;
				if (_tmp39_ == NULL) {
					_tmp36_ = TRUE;
				} else {
					GXmlCollection* _tmp40_;
					GXmlDomElement* _tmp41_;
					GXmlDomElement* _tmp42_;
					_tmp40_ = col;
					_tmp41_ = gxml_collection_get_element (_tmp40_);
					_tmp42_ = _tmp41_;
					_tmp36_ = !G_TYPE_CHECK_INSTANCE_TYPE (_tmp42_, GXML_TYPE_GOM_ELEMENT);
				}
				if (_tmp36_) {
					GError* _tmp43_;
					gboolean _tmp44_ = FALSE;
					_tmp43_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_INVALID_NODE_TYPE_ERROR, _ ("Invalid Element set to Collection"));
					_inner_error0_ = _tmp43_;
					g_propagate_error (error, _inner_error0_);
					G_IS_VALUE (&vc) ? (g_value_unset (&vc), NULL) : NULL;
					_g_object_unref0 (col);
					_g_param_spec_unref0 (pspec);
					(pspec_collection == NULL) ? NULL : (pspec_collection = (_g_list_free__g_param_spec_unref0_ (pspec_collection), NULL));
					return _tmp44_;
				}
				_tmp45_ = col;
				_tmp46_ = gxml_collection_get_items_name (_tmp45_);
				_tmp47_ = _tmp46_;
				_tmp48_ = g_utf8_strdown (_tmp47_, (gssize) -1);
				_tmp49_ = _tmp48_;
				_tmp50_ = gxml_parser_current_node_name (self);
				_tmp51_ = _tmp50_;
				_tmp52_ = g_utf8_strdown (_tmp51_, (gssize) -1);
				_tmp53_ = _tmp52_;
				_tmp54_ = g_strcmp0 (_tmp49_, _tmp53_) == 0;
				_g_free0 (_tmp53_);
				_g_free0 (_tmp51_);
				_g_free0 (_tmp49_);
				if (_tmp54_) {
					GXmlDomDocument* _tmp55_;
					GXmlDomDocument* _tmp56_;
					GXmlDomElement* obj = NULL;
					GXmlCollection* _tmp59_;
					GType _tmp60_;
					GType _tmp61_;
					GXmlDomNode* _tmp62_;
					GXmlDomNode* _tmp63_;
					GXmlDomDocument* _tmp64_;
					GXmlDomDocument* _tmp65_;
					GObject* _tmp66_;
					GObject* _tmp67_;
					GXmlDomElement* _tmp68_;
					GXmlDomElement* _tmp69_;
					GXmlDomNode* _tmp70_;
					GXmlDomNode* _tmp71_;
					GXmlDomElement* _tmp73_;
					GXmlCollection* _tmp75_;
					GXmlDomElement* _tmp76_;
					GXmlDomElement* _tmp78_;
					GXmlDomNode* _tmp79_;
					_tmp55_ = gxml_dom_node_get_owner_document (parent);
					_tmp56_ = _tmp55_;
					if (_tmp56_ == NULL) {
						GError* _tmp57_;
						gboolean _tmp58_ = FALSE;
						_tmp57_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_HIERARCHY_REQUEST_ERROR, _ ("No document is set to node"));
						_inner_error0_ = _tmp57_;
						g_propagate_error (error, _inner_error0_);
						G_IS_VALUE (&vc) ? (g_value_unset (&vc), NULL) : NULL;
						_g_object_unref0 (col);
						_g_param_spec_unref0 (pspec);
						(pspec_collection == NULL) ? NULL : (pspec_collection = (_g_list_free__g_param_spec_unref0_ (pspec_collection), NULL));
						return _tmp58_;
					}
					_tmp59_ = col;
					_tmp60_ = gxml_collection_get_items_type (_tmp59_);
					_tmp61_ = _tmp60_;
					_tmp62_ = gxml_parser_get_node (self);
					_tmp63_ = _tmp62_;
					_tmp64_ = gxml_dom_node_get_owner_document (_tmp63_);
					_tmp65_ = _tmp64_;
					_tmp66_ = g_object_new (_tmp61_, "owner-document", _tmp65_, NULL);
					_tmp67_ = G_IS_INITIALLY_UNOWNED (_tmp66_) ? g_object_ref_sink (_tmp66_) : _tmp66_;
					_tmp68_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp67_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp67_) : NULL;
					if (_tmp68_ == NULL) {
						_g_object_unref0 (_tmp67_);
					}
					obj = _tmp68_;
					_tmp69_ = obj;
					_tmp70_ = gxml_dom_node_append_child (parent, (GXmlDomNode*) _tmp69_, &_inner_error0_);
					_tmp71_ = _tmp70_;
					_g_object_unref0 (_tmp71_);
					if (G_UNLIKELY (_inner_error0_ != NULL)) {
						gboolean _tmp72_ = FALSE;
						g_propagate_error (error, _inner_error0_);
						_g_object_unref0 (obj);
						G_IS_VALUE (&vc) ? (g_value_unset (&vc), NULL) : NULL;
						_g_object_unref0 (col);
						_g_param_spec_unref0 (pspec);
						(pspec_collection == NULL) ? NULL : (pspec_collection = (_g_list_free__g_param_spec_unref0_ (pspec_collection), NULL));
						return _tmp72_;
					}
					_tmp73_ = obj;
					gxml_parser_read_element (self, G_TYPE_CHECK_INSTANCE_TYPE (_tmp73_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp73_) : NULL, &_inner_error0_);
					if (G_UNLIKELY (_inner_error0_ != NULL)) {
						gboolean _tmp74_ = FALSE;
						g_propagate_error (error, _inner_error0_);
						_g_object_unref0 (obj);
						G_IS_VALUE (&vc) ? (g_value_unset (&vc), NULL) : NULL;
						_g_object_unref0 (col);
						_g_param_spec_unref0 (pspec);
						(pspec_collection == NULL) ? NULL : (pspec_collection = (_g_list_free__g_param_spec_unref0_ (pspec_collection), NULL));
						return _tmp74_;
					}
					_tmp75_ = col;
					_tmp76_ = obj;
					gxml_collection_append (_tmp75_, _tmp76_, &_inner_error0_);
					if (G_UNLIKELY (_inner_error0_ != NULL)) {
						gboolean _tmp77_ = FALSE;
						g_propagate_error (error, _inner_error0_);
						_g_object_unref0 (obj);
						G_IS_VALUE (&vc) ? (g_value_unset (&vc), NULL) : NULL;
						_g_object_unref0 (col);
						_g_param_spec_unref0 (pspec);
						(pspec_collection == NULL) ? NULL : (pspec_collection = (_g_list_free__g_param_spec_unref0_ (pspec_collection), NULL));
						return _tmp77_;
					}
					_tmp78_ = obj;
					_tmp79_ = _g_object_ref0 ((GXmlDomNode*) _tmp78_);
					_g_object_unref0 (_vala_element);
					_vala_element = _tmp79_;
					result = TRUE;
					_g_object_unref0 (obj);
					G_IS_VALUE (&vc) ? (g_value_unset (&vc), NULL) : NULL;
					_g_object_unref0 (col);
					_g_param_spec_unref0 (pspec);
					(pspec_collection == NULL) ? NULL : (pspec_collection = (_g_list_free__g_param_spec_unref0_ (pspec_collection), NULL));
					if (element) {
						*element = _vala_element;
					} else {
						_g_object_unref0 (_vala_element);
					}
					return result;
				}
				G_IS_VALUE (&vc) ? (g_value_unset (&vc), NULL) : NULL;
				_g_object_unref0 (col);
				_g_param_spec_unref0 (pspec);
			}
		}
		(pspec_collection == NULL) ? NULL : (pspec_collection = (_g_list_free__g_param_spec_unref0_ (pspec_collection), NULL));
	}
	result = FALSE;
	if (element) {
		*element = _vala_element;
	} else {
		_g_object_unref0 (_vala_element);
	}
	return result;
}

gboolean
gxml_parser_add_element_collection (GXmlParser* self,
                                    GXmlDomNode* parent,
                                    GXmlDomNode* * element,
                                    GError** error)
{
	g_return_val_if_fail (self != NULL, FALSE);
	return GXML_PARSER_GET_INTERFACE (self)->add_element_collection (self, parent, element, error);
}

/**
   * Read all childs node feed by stream.
   */
void
gxml_parser_read_child_nodes_stream (GXmlParser* self,
                                     GInputStream* istream,
                                     GError** error)
{
	g_return_if_fail (self != NULL);
	GXML_PARSER_GET_INTERFACE (self)->read_child_nodes_stream (self, istream, error);
}

/**
   * Read childs nodes from string
   */
static guint8*
string_get_data (const gchar* self,
                 gint* result_length1)
{
	guint8* result;
	guint8* res = NULL;
	gint res_length1;
	gint _res_size_;
	gint _tmp0_;
	gint _tmp1_;
	guint8* _tmp2_;
	gint _tmp2__length1;
	guint8* _tmp3_;
	gint _tmp3__length1;
	g_return_val_if_fail (self != NULL, NULL);
	res = (guint8*) self;
	res_length1 = -1;
	_res_size_ = res_length1;
	_tmp0_ = strlen (self);
	_tmp1_ = _tmp0_;
	res_length1 = (gint) _tmp1_;
	_tmp2_ = res;
	_tmp2__length1 = res_length1;
	_tmp3_ = _tmp2_;
	_tmp3__length1 = _tmp2__length1;
	if (result_length1) {
		*result_length1 = _tmp3__length1;
	}
	result = _tmp3_;
	return result;
}

static guint8*
_vala_array_dup7 (guint8* self,
                  int length)
{
	return g_memdup (self, length * sizeof (guint8));
}

static void
gxml_parser_real_read_child_nodes_string (GXmlParser* self,
                                          const gchar* str,
                                          GError** error)
{
	GMemoryInputStream* stream = NULL;
	guint8* _tmp1_;
	gint _tmp1__length1;
	guint8* _tmp2_;
	gint _tmp2__length1;
	guint8* _tmp3_;
	gint _tmp3__length1;
	GDestroyNotify _tmp4_;
	GMemoryInputStream* _tmp5_;
	GError* _inner_error0_ = NULL;
	g_return_if_fail (str != NULL);
	if (g_strcmp0 (str, "") == 0) {
		GError* _tmp0_;
		_tmp0_ = g_error_new_literal (GXML_PARSER_ERROR, GXML_PARSER_ERROR_INVALID_DATA_ERROR, _ ("Invalid document string, it is empty or is not allowed"));
		_inner_error0_ = _tmp0_;
		g_propagate_error (error, _inner_error0_);
		return;
	}
	_tmp1_ = string_get_data (str, &_tmp1__length1);
	_tmp2_ = _tmp1_;
	_tmp2__length1 = _tmp1__length1;
	_tmp3_ = (_tmp2_ != NULL) ? _vala_array_dup7 (_tmp2_, _tmp2__length1) : ((gpointer) _tmp2_);
	_tmp3__length1 = _tmp2__length1;
	_tmp4_ = g_free;
	_tmp5_ = (GMemoryInputStream*) g_memory_input_stream_new_from_data (_tmp3_, _tmp3__length1, _tmp4_);
	stream = _tmp5_;
	gxml_parser_read_child_nodes_stream (self, (GInputStream*) stream, &_inner_error0_);
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		_g_object_unref0 (stream);
		return;
	}
	_g_object_unref0 (stream);
}

void
gxml_parser_read_child_nodes_string (GXmlParser* self,
                                     const gchar* str,
                                     GError** error)
{
	g_return_if_fail (self != NULL);
	GXML_PARSER_GET_INTERFACE (self)->read_child_nodes_string (self, str, error);
}

/**
   * Reads all child nodes as string
   */
gchar*
gxml_parser_read_unparsed (GXmlParser* self,
                           GError** error)
{
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_PARSER_GET_INTERFACE (self)->read_unparsed (self, error);
}

/**
   * Use parser to go to next parsed node.
   */
gboolean
gxml_parser_move_next_node (GXmlParser* self,
                            GError** error)
{
	g_return_val_if_fail (self != NULL, FALSE);
	return GXML_PARSER_GET_INTERFACE (self)->move_next_node (self, error);
}

/**
   * Check if current node has childs.
   */
gboolean
gxml_parser_current_is_empty_element (GXmlParser* self)
{
	g_return_val_if_fail (self != NULL, FALSE);
	return GXML_PARSER_GET_INTERFACE (self)->current_is_empty_element (self);
}

/**
   * Check if current node found by parser, is a {@link DomElement}
   */
gboolean
gxml_parser_current_is_element (GXmlParser* self)
{
	g_return_val_if_fail (self != NULL, FALSE);
	return GXML_PARSER_GET_INTERFACE (self)->current_is_element (self);
}

/**
   * Check if current node found by parser, is a {@link DomDocument}
   */
gboolean
gxml_parser_current_is_document (GXmlParser* self)
{
	g_return_val_if_fail (self != NULL, FALSE);
	return GXML_PARSER_GET_INTERFACE (self)->current_is_document (self);
}

/**
   * Returns current node's local name, found by parser.
   */
gchar*
gxml_parser_current_node_name (GXmlParser* self)
{
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_PARSER_GET_INTERFACE (self)->current_node_name (self);
}

/**
   * Creates a new {@link DomElement} and append it as a child of parent.
   */
GXmlDomElement*
gxml_parser_create_element (GXmlParser* self,
                            GXmlDomNode* parent,
                            GError** error)
{
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_PARSER_GET_INTERFACE (self)->create_element (self, parent, error);
}

/**
   * Reads an element's attributes, setting its values and taking care about their
   * namespaces.
   */
void
gxml_parser_read_element (GXmlParser* self,
                          GXmlDomElement* element,
                          GError** error)
{
	g_return_if_fail (self != NULL);
	GXML_PARSER_GET_INTERFACE (self)->read_element (self, element, error);
}

gboolean
gxml_parser_get_backup (GXmlParser* self)
{
	g_return_val_if_fail (self != NULL, FALSE);
	return GXML_PARSER_GET_INTERFACE (self)->get_backup (self);
}

void
gxml_parser_set_backup (GXmlParser* self,
                        gboolean value)
{
	g_return_if_fail (self != NULL);
	GXML_PARSER_GET_INTERFACE (self)->set_backup (self, value);
}

gboolean
gxml_parser_get_indent (GXmlParser* self)
{
	g_return_val_if_fail (self != NULL, FALSE);
	return GXML_PARSER_GET_INTERFACE (self)->get_indent (self);
}

void
gxml_parser_set_indent (GXmlParser* self,
                        gboolean value)
{
	g_return_if_fail (self != NULL);
	GXML_PARSER_GET_INTERFACE (self)->set_indent (self, value);
}

GCancellable*
gxml_parser_get_cancellable (GXmlParser* self)
{
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_PARSER_GET_INTERFACE (self)->get_cancellable (self);
}

void
gxml_parser_set_cancellable (GXmlParser* self,
                             GCancellable* value)
{
	g_return_if_fail (self != NULL);
	GXML_PARSER_GET_INTERFACE (self)->set_cancellable (self, value);
}

GXmlDomNode*
gxml_parser_get_node (GXmlParser* self)
{
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_PARSER_GET_INTERFACE (self)->get_node (self);
}

static void
gxml_parser_default_init (GXmlParserIface * iface,
                          gpointer iface_data)
{
	/**
	   * Controls if, when writing to a file, a backup should
	   * be created.
	   */
	g_object_interface_install_property (iface, g_param_spec_boolean ("backup", "backup", "backup", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	   * Controls if, when writing, identation should be used.
	   */
	g_object_interface_install_property (iface, g_param_spec_boolean ("indent", "indent", "indent", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	   * Controls if, when writing, identation should be used.
	   */
	g_object_interface_install_property (iface, g_param_spec_object ("cancellable", "cancellable", "cancellable", g_cancellable_get_type (), G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	   * A {@link GXml.DomDocument} to read to or write from
	   */
	g_object_interface_install_property (iface, g_param_spec_object ("node", "node", "node", GXML_TYPE_DOM_NODE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	iface->write_file = gxml_parser_real_write_file;
	iface->write_file_async = gxml_parser_real_write_file_async;
	iface->write_file_finish = gxml_parser_real_write_file_finish;
	iface->read_file = gxml_parser_real_read_file;
	iface->read_file_async = gxml_parser_real_read_file_async;
	iface->read_file_finish = gxml_parser_real_read_file_finish;
	iface->read_child_nodes = gxml_parser_real_read_child_nodes;
	iface->read_child_nodes_async = gxml_parser_real_read_child_nodes_async;
	iface->read_child_nodes_finish = gxml_parser_real_read_child_nodes_finish;
	iface->read_child_element = gxml_parser_real_read_child_element;
	iface->read_element_property = gxml_parser_real_read_element_property;
	iface->add_element_collection = gxml_parser_real_add_element_collection;
	iface->read_child_nodes_string = gxml_parser_real_read_child_nodes_string;
}

/**
 * XML parser engine for {@link DomDocument} implementations.
 */
GType
gxml_parser_get_type (void)
{
	static volatile gsize gxml_parser_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_parser_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlParserIface), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_parser_default_init, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_parser_type_id;
		gxml_parser_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlParser", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_parser_type_id, G_TYPE_OBJECT);
		g_once_init_leave (&gxml_parser_type_id__volatile, gxml_parser_type_id);
	}
	return gxml_parser_type_id__volatile;
}

